// Generated by https://github.com/juliettef/IconFontCppHeaders script GenerateIconFontCppHeaders.py for language C89
// from icons.yml
// for use with fa-light-300.ttf, fa-regular-400.ttf, fa-solid-900.ttf
#pragma once

#define FONT_ICON_FILE_NAME_FAL "fa-light-300.ttf"
#define FONT_ICON_FILE_NAME_FAR "fa-regular-400.ttf"
#define FONT_ICON_FILE_NAME_FAS "fa-solid-900.ttf"

#define ICON_MIN_FA 0xe000
#define ICON_MAX_FA 0xf8ff
#define ICON_FA_ABACUS "\xef\x99\x80"
#define ICON_FA_ACORN "\xef\x9a\xae"
#define ICON_FA_AD "\xef\x99\x81"
#define ICON_FA_ADDRESS_BOOK "\xef\x8a\xb9"
#define ICON_FA_ADDRESS_CARD "\xef\x8a\xbb"
#define ICON_FA_ADJUST "\xef\x81\x82"
#define ICON_FA_AIR_CONDITIONER "\xef\xa3\xb4"
#define ICON_FA_AIR_FRESHENER "\xef\x97\x90"
#define ICON_FA_ALARM_CLOCK "\xef\x8d\x8e"
#define ICON_FA_ALARM_EXCLAMATION "\xef\xa1\x83"
#define ICON_FA_ALARM_PLUS "\xef\xa1\x84"
#define ICON_FA_ALARM_SNOOZE "\xef\xa1\x85"
#define ICON_FA_ALBUM "\xef\xa2\x9f"
#define ICON_FA_ALBUM_COLLECTION "\xef\xa2\xa0"
#define ICON_FA_ALICORN "\xef\x9a\xb0"
#define ICON_FA_ALIEN "\xef\xa3\xb5"
#define ICON_FA_ALIEN_MONSTER "\xef\xa3\xb6"
#define ICON_FA_ALIGN_CENTER "\xef\x80\xb7"
#define ICON_FA_ALIGN_JUSTIFY "\xef\x80\xb9"
#define ICON_FA_ALIGN_LEFT "\xef\x80\xb6"
#define ICON_FA_ALIGN_RIGHT "\xef\x80\xb8"
#define ICON_FA_ALIGN_SLASH "\xef\xa1\x86"
#define ICON_FA_ALLERGIES "\xef\x91\xa1"
#define ICON_FA_AMBULANCE "\xef\x83\xb9"
#define ICON_FA_AMERICAN_SIGN_LANGUAGE_INTERPRETING "\xef\x8a\xa3"
#define ICON_FA_AMP_GUITAR "\xef\xa2\xa1"
#define ICON_FA_ANALYTICS "\xef\x99\x83"
#define ICON_FA_ANCHOR "\xef\x84\xbd"
#define ICON_FA_ANGEL "\xef\x9d\xb9"
#define ICON_FA_ANGLE_DOUBLE_DOWN "\xef\x84\x83"
#define ICON_FA_ANGLE_DOUBLE_LEFT "\xef\x84\x80"
#define ICON_FA_ANGLE_DOUBLE_RIGHT "\xef\x84\x81"
#define ICON_FA_ANGLE_DOUBLE_UP "\xef\x84\x82"
#define ICON_FA_ANGLE_DOWN "\xef\x84\x87"
#define ICON_FA_ANGLE_LEFT "\xef\x84\x84"
#define ICON_FA_ANGLE_RIGHT "\xef\x84\x85"
#define ICON_FA_ANGLE_UP "\xef\x84\x86"
#define ICON_FA_ANGRY "\xef\x95\x96"
#define ICON_FA_ANKH "\xef\x99\x84"
#define ICON_FA_APPLE_ALT "\xef\x97\x91"
#define ICON_FA_APPLE_CRATE "\xef\x9a\xb1"
#define ICON_FA_ARCHIVE "\xef\x86\x87"
#define ICON_FA_ARCHWAY "\xef\x95\x97"
#define ICON_FA_ARROW_ALT_CIRCLE_DOWN "\xef\x8d\x98"
#define ICON_FA_ARROW_ALT_CIRCLE_LEFT "\xef\x8d\x99"
#define ICON_FA_ARROW_ALT_CIRCLE_RIGHT "\xef\x8d\x9a"
#define ICON_FA_ARROW_ALT_CIRCLE_UP "\xef\x8d\x9b"
#define ICON_FA_ARROW_ALT_DOWN "\xef\x8d\x94"
#define ICON_FA_ARROW_ALT_FROM_BOTTOM "\xef\x8d\x86"
#define ICON_FA_ARROW_ALT_FROM_LEFT "\xef\x8d\x87"
#define ICON_FA_ARROW_ALT_FROM_RIGHT "\xef\x8d\x88"
#define ICON_FA_ARROW_ALT_FROM_TOP "\xef\x8d\x89"
#define ICON_FA_ARROW_ALT_LEFT "\xef\x8d\x95"
#define ICON_FA_ARROW_ALT_RIGHT "\xef\x8d\x96"
#define ICON_FA_ARROW_ALT_SQUARE_DOWN "\xef\x8d\x90"
#define ICON_FA_ARROW_ALT_SQUARE_LEFT "\xef\x8d\x91"
#define ICON_FA_ARROW_ALT_SQUARE_RIGHT "\xef\x8d\x92"
#define ICON_FA_ARROW_ALT_SQUARE_UP "\xef\x8d\x93"
#define ICON_FA_ARROW_ALT_TO_BOTTOM "\xef\x8d\x8a"
#define ICON_FA_ARROW_ALT_TO_LEFT "\xef\x8d\x8b"
#define ICON_FA_ARROW_ALT_TO_RIGHT "\xef\x8d\x8c"
#define ICON_FA_ARROW_ALT_TO_TOP "\xef\x8d\x8d"
#define ICON_FA_ARROW_ALT_UP "\xef\x8d\x97"
#define ICON_FA_ARROW_CIRCLE_DOWN "\xef\x82\xab"
#define ICON_FA_ARROW_CIRCLE_LEFT "\xef\x82\xa8"
#define ICON_FA_ARROW_CIRCLE_RIGHT "\xef\x82\xa9"
#define ICON_FA_ARROW_CIRCLE_UP "\xef\x82\xaa"
#define ICON_FA_ARROW_DOWN "\xef\x81\xa3"
#define ICON_FA_ARROW_FROM_BOTTOM "\xef\x8d\x82"
#define ICON_FA_ARROW_FROM_LEFT "\xef\x8d\x83"
#define ICON_FA_ARROW_FROM_RIGHT "\xef\x8d\x84"
#define ICON_FA_ARROW_FROM_TOP "\xef\x8d\x85"
#define ICON_FA_ARROW_LEFT "\xef\x81\xa0"
#define ICON_FA_ARROW_RIGHT "\xef\x81\xa1"
#define ICON_FA_ARROW_SQUARE_DOWN "\xef\x8c\xb9"
#define ICON_FA_ARROW_SQUARE_LEFT "\xef\x8c\xba"
#define ICON_FA_ARROW_SQUARE_RIGHT "\xef\x8c\xbb"
#define ICON_FA_ARROW_SQUARE_UP "\xef\x8c\xbc"
#define ICON_FA_ARROW_TO_BOTTOM "\xef\x8c\xbd"
#define ICON_FA_ARROW_TO_LEFT "\xef\x8c\xbe"
#define ICON_FA_ARROW_TO_RIGHT "\xef\x8d\x80"
#define ICON_FA_ARROW_TO_TOP "\xef\x8d\x81"
#define ICON_FA_ARROW_UP "\xef\x81\xa2"
#define ICON_FA_ARROWS "\xef\x81\x87"
#define ICON_FA_ARROWS_ALT "\xef\x82\xb2"
#define ICON_FA_ARROWS_ALT_H "\xef\x8c\xb7"
#define ICON_FA_ARROWS_ALT_V "\xef\x8c\xb8"
#define ICON_FA_ARROWS_H "\xef\x81\xbe"
#define ICON_FA_ARROWS_V "\xef\x81\xbd"
#define ICON_FA_ASSISTIVE_LISTENING_SYSTEMS "\xef\x8a\xa2"
#define ICON_FA_ASTERISK "\xef\x81\xa9"
#define ICON_FA_AT "\xef\x87\xba"
#define ICON_FA_ATLAS "\xef\x95\x98"
#define ICON_FA_ATOM "\xef\x97\x92"
#define ICON_FA_ATOM_ALT "\xef\x97\x93"
#define ICON_FA_AUDIO_DESCRIPTION "\xef\x8a\x9e"
#define ICON_FA_AWARD "\xef\x95\x99"
#define ICON_FA_AXE "\xef\x9a\xb2"
#define ICON_FA_AXE_BATTLE "\xef\x9a\xb3"
#define ICON_FA_BABY "\xef\x9d\xbc"
#define ICON_FA_BABY_CARRIAGE "\xef\x9d\xbd"
#define ICON_FA_BACKPACK "\xef\x97\x94"
#define ICON_FA_BACKSPACE "\xef\x95\x9a"
#define ICON_FA_BACKWARD "\xef\x81\x8a"
#define ICON_FA_BACON "\xef\x9f\xa5"
#define ICON_FA_BACTERIA "\xee\x81\x99"
#define ICON_FA_BACTERIUM "\xee\x81\x9a"
#define ICON_FA_BADGE "\xef\x8c\xb5"
#define ICON_FA_BADGE_CHECK "\xef\x8c\xb6"
#define ICON_FA_BADGE_DOLLAR "\xef\x99\x85"
#define ICON_FA_BADGE_PERCENT "\xef\x99\x86"
#define ICON_FA_BADGE_SHERIFF "\xef\xa2\xa2"
#define ICON_FA_BADGER_HONEY "\xef\x9a\xb4"
#define ICON_FA_BAGS_SHOPPING "\xef\xa1\x87"
#define ICON_FA_BAHAI "\xef\x99\xa6"
#define ICON_FA_BALANCE_SCALE "\xef\x89\x8e"
#define ICON_FA_BALANCE_SCALE_LEFT "\xef\x94\x95"
#define ICON_FA_BALANCE_SCALE_RIGHT "\xef\x94\x96"
#define ICON_FA_BALL_PILE "\xef\x9d\xbe"
#define ICON_FA_BALLOT "\xef\x9c\xb2"
#define ICON_FA_BALLOT_CHECK "\xef\x9c\xb3"
#define ICON_FA_BAN "\xef\x81\x9e"
#define ICON_FA_BAND_AID "\xef\x91\xa2"
#define ICON_FA_BANJO "\xef\xa2\xa3"
#define ICON_FA_BARCODE "\xef\x80\xaa"
#define ICON_FA_BARCODE_ALT "\xef\x91\xa3"
#define ICON_FA_BARCODE_READ "\xef\x91\xa4"
#define ICON_FA_BARCODE_SCAN "\xef\x91\xa5"
#define ICON_FA_BARS "\xef\x83\x89"
#define ICON_FA_BASEBALL "\xef\x90\xb2"
#define ICON_FA_BASEBALL_BALL "\xef\x90\xb3"
#define ICON_FA_BASKETBALL_BALL "\xef\x90\xb4"
#define ICON_FA_BASKETBALL_HOOP "\xef\x90\xb5"
#define ICON_FA_BAT "\xef\x9a\xb5"
#define ICON_FA_BATH "\xef\x8b\x8d"
#define ICON_FA_BATTERY_BOLT "\xef\x8d\xb6"
#define ICON_FA_BATTERY_EMPTY "\xef\x89\x84"
#define ICON_FA_BATTERY_FULL "\xef\x89\x80"
#define ICON_FA_BATTERY_HALF "\xef\x89\x82"
#define ICON_FA_BATTERY_QUARTER "\xef\x89\x83"
#define ICON_FA_BATTERY_SLASH "\xef\x8d\xb7"
#define ICON_FA_BATTERY_THREE_QUARTERS "\xef\x89\x81"
#define ICON_FA_BED "\xef\x88\xb6"
#define ICON_FA_BED_ALT "\xef\xa3\xb7"
#define ICON_FA_BED_BUNK "\xef\xa3\xb8"
#define ICON_FA_BED_EMPTY "\xef\xa3\xb9"
#define ICON_FA_BEER "\xef\x83\xbc"
#define ICON_FA_BELL "\xef\x83\xb3"
#define ICON_FA_BELL_EXCLAMATION "\xef\xa1\x88"
#define ICON_FA_BELL_ON "\xef\xa3\xba"
#define ICON_FA_BELL_PLUS "\xef\xa1\x89"
#define ICON_FA_BELL_SCHOOL "\xef\x97\x95"
#define ICON_FA_BELL_SCHOOL_SLASH "\xef\x97\x96"
#define ICON_FA_BELL_SLASH "\xef\x87\xb6"
#define ICON_FA_BELLS "\xef\x9d\xbf"
#define ICON_FA_BETAMAX "\xef\xa2\xa4"
#define ICON_FA_BEZIER_CURVE "\xef\x95\x9b"
#define ICON_FA_BIBLE "\xef\x99\x87"
#define ICON_FA_BICYCLE "\xef\x88\x86"
#define ICON_FA_BIKING "\xef\xa1\x8a"
#define ICON_FA_BIKING_MOUNTAIN "\xef\xa1\x8b"
#define ICON_FA_BINOCULARS "\xef\x87\xa5"
#define ICON_FA_BIOHAZARD "\xef\x9e\x80"
#define ICON_FA_BIRTHDAY_CAKE "\xef\x87\xbd"
#define ICON_FA_BLANKET "\xef\x92\x98"
#define ICON_FA_BLENDER "\xef\x94\x97"
#define ICON_FA_BLENDER_PHONE "\xef\x9a\xb6"
#define ICON_FA_BLIND "\xef\x8a\x9d"
#define ICON_FA_BLINDS "\xef\xa3\xbb"
#define ICON_FA_BLINDS_OPEN "\xef\xa3\xbc"
#define ICON_FA_BLINDS_RAISED "\xef\xa3\xbd"
#define ICON_FA_BLOG "\xef\x9e\x81"
#define ICON_FA_BOLD "\xef\x80\xb2"
#define ICON_FA_BOLT "\xef\x83\xa7"
#define ICON_FA_BOMB "\xef\x87\xa2"
#define ICON_FA_BONE "\xef\x97\x97"
#define ICON_FA_BONE_BREAK "\xef\x97\x98"
#define ICON_FA_BONG "\xef\x95\x9c"
#define ICON_FA_BOOK "\xef\x80\xad"
#define ICON_FA_BOOK_ALT "\xef\x97\x99"
#define ICON_FA_BOOK_DEAD "\xef\x9a\xb7"
#define ICON_FA_BOOK_HEART "\xef\x92\x99"
#define ICON_FA_BOOK_MEDICAL "\xef\x9f\xa6"
#define ICON_FA_BOOK_OPEN "\xef\x94\x98"
#define ICON_FA_BOOK_READER "\xef\x97\x9a"
#define ICON_FA_BOOK_SPELLS "\xef\x9a\xb8"
#define ICON_FA_BOOK_USER "\xef\x9f\xa7"
#define ICON_FA_BOOKMARK "\xef\x80\xae"
#define ICON_FA_BOOKS "\xef\x97\x9b"
#define ICON_FA_BOOKS_MEDICAL "\xef\x9f\xa8"
#define ICON_FA_BOOMBOX "\xef\xa2\xa5"
#define ICON_FA_BOOT "\xef\x9e\x82"
#define ICON_FA_BOOTH_CURTAIN "\xef\x9c\xb4"
#define ICON_FA_BORDER_ALL "\xef\xa1\x8c"
#define ICON_FA_BORDER_BOTTOM "\xef\xa1\x8d"
#define ICON_FA_BORDER_CENTER_H "\xef\xa2\x9c"
#define ICON_FA_BORDER_CENTER_V "\xef\xa2\x9d"
#define ICON_FA_BORDER_INNER "\xef\xa1\x8e"
#define ICON_FA_BORDER_LEFT "\xef\xa1\x8f"
#define ICON_FA_BORDER_NONE "\xef\xa1\x90"
#define ICON_FA_BORDER_OUTER "\xef\xa1\x91"
#define ICON_FA_BORDER_RIGHT "\xef\xa1\x92"
#define ICON_FA_BORDER_STYLE "\xef\xa1\x93"
#define ICON_FA_BORDER_STYLE_ALT "\xef\xa1\x94"
#define ICON_FA_BORDER_TOP "\xef\xa1\x95"
#define ICON_FA_BOW_ARROW "\xef\x9a\xb9"
#define ICON_FA_BOWLING_BALL "\xef\x90\xb6"
#define ICON_FA_BOWLING_PINS "\xef\x90\xb7"
#define ICON_FA_BOX "\xef\x91\xa6"
#define ICON_FA_BOX_ALT "\xef\x92\x9a"
#define ICON_FA_BOX_BALLOT "\xef\x9c\xb5"
#define ICON_FA_BOX_CHECK "\xef\x91\xa7"
#define ICON_FA_BOX_FRAGILE "\xef\x92\x9b"
#define ICON_FA_BOX_FULL "\xef\x92\x9c"
#define ICON_FA_BOX_HEART "\xef\x92\x9d"
#define ICON_FA_BOX_OPEN "\xef\x92\x9e"
#define ICON_FA_BOX_TISSUE "\xee\x81\x9b"
#define ICON_FA_BOX_UP "\xef\x92\x9f"
#define ICON_FA_BOX_USD "\xef\x92\xa0"
#define ICON_FA_BOXES "\xef\x91\xa8"
#define ICON_FA_BOXES_ALT "\xef\x92\xa1"
#define ICON_FA_BOXING_GLOVE "\xef\x90\xb8"
#define ICON_FA_BRACKETS "\xef\x9f\xa9"
#define ICON_FA_BRACKETS_CURLY "\xef\x9f\xaa"
#define ICON_FA_BRAILLE "\xef\x8a\xa1"
#define ICON_FA_BRAIN "\xef\x97\x9c"
#define ICON_FA_BREAD_LOAF "\xef\x9f\xab"
#define ICON_FA_BREAD_SLICE "\xef\x9f\xac"
#define ICON_FA_BRIEFCASE "\xef\x82\xb1"
#define ICON_FA_BRIEFCASE_MEDICAL "\xef\x91\xa9"
#define ICON_FA_BRING_FORWARD "\xef\xa1\x96"
#define ICON_FA_BRING_FRONT "\xef\xa1\x97"
#define ICON_FA_BROADCAST_TOWER "\xef\x94\x99"
#define ICON_FA_BROOM "\xef\x94\x9a"
#define ICON_FA_BROWSER "\xef\x8d\xbe"
#define ICON_FA_BRUSH "\xef\x95\x9d"
#define ICON_FA_BUG "\xef\x86\x88"
#define ICON_FA_BUILDING "\xef\x86\xad"
#define ICON_FA_BULLHORN "\xef\x82\xa1"
#define ICON_FA_BULLSEYE "\xef\x85\x80"
#define ICON_FA_BULLSEYE_ARROW "\xef\x99\x88"
#define ICON_FA_BULLSEYE_POINTER "\xef\x99\x89"
#define ICON_FA_BURGER_SODA "\xef\xa1\x98"
#define ICON_FA_BURN "\xef\x91\xaa"
#define ICON_FA_BURRITO "\xef\x9f\xad"
#define ICON_FA_BUS "\xef\x88\x87"
#define ICON_FA_BUS_ALT "\xef\x95\x9e"
#define ICON_FA_BUS_SCHOOL "\xef\x97\x9d"
#define ICON_FA_BUSINESS_TIME "\xef\x99\x8a"
#define ICON_FA_CABINET_FILING "\xef\x99\x8b"
#define ICON_FA_CACTUS "\xef\xa2\xa7"
#define ICON_FA_CALCULATOR "\xef\x87\xac"
#define ICON_FA_CALCULATOR_ALT "\xef\x99\x8c"
#define ICON_FA_CALENDAR "\xef\x84\xb3"
#define ICON_FA_CALENDAR_ALT "\xef\x81\xb3"
#define ICON_FA_CALENDAR_CHECK "\xef\x89\xb4"
#define ICON_FA_CALENDAR_DAY "\xef\x9e\x83"
#define ICON_FA_CALENDAR_EDIT "\xef\x8c\xb3"
#define ICON_FA_CALENDAR_EXCLAMATION "\xef\x8c\xb4"
#define ICON_FA_CALENDAR_MINUS "\xef\x89\xb2"
#define ICON_FA_CALENDAR_PLUS "\xef\x89\xb1"
#define ICON_FA_CALENDAR_STAR "\xef\x9c\xb6"
#define ICON_FA_CALENDAR_TIMES "\xef\x89\xb3"
#define ICON_FA_CALENDAR_WEEK "\xef\x9e\x84"
#define ICON_FA_CAMCORDER "\xef\xa2\xa8"
#define ICON_FA_CAMERA "\xef\x80\xb0"
#define ICON_FA_CAMERA_ALT "\xef\x8c\xb2"
#define ICON_FA_CAMERA_HOME "\xef\xa3\xbe"
#define ICON_FA_CAMERA_MOVIE "\xef\xa2\xa9"
#define ICON_FA_CAMERA_POLAROID "\xef\xa2\xaa"
#define ICON_FA_CAMERA_RETRO "\xef\x82\x83"
#define ICON_FA_CAMPFIRE "\xef\x9a\xba"
#define ICON_FA_CAMPGROUND "\xef\x9a\xbb"
#define ICON_FA_CANDLE_HOLDER "\xef\x9a\xbc"
#define ICON_FA_CANDY_CANE "\xef\x9e\x86"
#define ICON_FA_CANDY_CORN "\xef\x9a\xbd"
#define ICON_FA_CANNABIS "\xef\x95\x9f"
#define ICON_FA_CAPSULES "\xef\x91\xab"
#define ICON_FA_CAR "\xef\x86\xb9"
#define ICON_FA_CAR_ALT "\xef\x97\x9e"
#define ICON_FA_CAR_BATTERY "\xef\x97\x9f"
#define ICON_FA_CAR_BUILDING "\xef\xa1\x99"
#define ICON_FA_CAR_BUMP "\xef\x97\xa0"
#define ICON_FA_CAR_BUS "\xef\xa1\x9a"
#define ICON_FA_CAR_CRASH "\xef\x97\xa1"
#define ICON_FA_CAR_GARAGE "\xef\x97\xa2"
#define ICON_FA_CAR_MECHANIC "\xef\x97\xa3"
#define ICON_FA_CAR_SIDE "\xef\x97\xa4"
#define ICON_FA_CAR_TILT "\xef\x97\xa5"
#define ICON_FA_CAR_WASH "\xef\x97\xa6"
#define ICON_FA_CARAVAN "\xef\xa3\xbf"
#define ICON_FA_CARAVAN_ALT "\xee\x80\x80"
#define ICON_FA_CARET_CIRCLE_DOWN "\xef\x8c\xad"
#define ICON_FA_CARET_CIRCLE_LEFT "\xef\x8c\xae"
#define ICON_FA_CARET_CIRCLE_RIGHT "\xef\x8c\xb0"
#define ICON_FA_CARET_CIRCLE_UP "\xef\x8c\xb1"
#define ICON_FA_CARET_DOWN "\xef\x83\x97"
#define ICON_FA_CARET_LEFT "\xef\x83\x99"
#define ICON_FA_CARET_RIGHT "\xef\x83\x9a"
#define ICON_FA_CARET_SQUARE_DOWN "\xef\x85\x90"
#define ICON_FA_CARET_SQUARE_LEFT "\xef\x86\x91"
#define ICON_FA_CARET_SQUARE_RIGHT "\xef\x85\x92"
#define ICON_FA_CARET_SQUARE_UP "\xef\x85\x91"
#define ICON_FA_CARET_UP "\xef\x83\x98"
#define ICON_FA_CARROT "\xef\x9e\x87"
#define ICON_FA_CARS "\xef\xa1\x9b"
#define ICON_FA_CART_ARROW_DOWN "\xef\x88\x98"
#define ICON_FA_CART_PLUS "\xef\x88\x97"
#define ICON_FA_CASH_REGISTER "\xef\x9e\x88"
#define ICON_FA_CASSETTE_TAPE "\xef\xa2\xab"
#define ICON_FA_CAT "\xef\x9a\xbe"
#define ICON_FA_CAT_SPACE "\xee\x80\x81"
#define ICON_FA_CAULDRON "\xef\x9a\xbf"
#define ICON_FA_CCTV "\xef\xa2\xac"
#define ICON_FA_CERTIFICATE "\xef\x82\xa3"
#define ICON_FA_CHAIR "\xef\x9b\x80"
#define ICON_FA_CHAIR_OFFICE "\xef\x9b\x81"
#define ICON_FA_CHALKBOARD "\xef\x94\x9b"
#define ICON_FA_CHALKBOARD_TEACHER "\xef\x94\x9c"
#define ICON_FA_CHARGING_STATION "\xef\x97\xa7"
#define ICON_FA_CHART_AREA "\xef\x87\xbe"
#define ICON_FA_CHART_BAR "\xef\x82\x80"
#define ICON_FA_CHART_LINE "\xef\x88\x81"
#define ICON_FA_CHART_LINE_DOWN "\xef\x99\x8d"
#define ICON_FA_CHART_NETWORK "\xef\x9e\x8a"
#define ICON_FA_CHART_PIE "\xef\x88\x80"
#define ICON_FA_CHART_PIE_ALT "\xef\x99\x8e"
#define ICON_FA_CHART_SCATTER "\xef\x9f\xae"
#define ICON_FA_CHECK "\xef\x80\x8c"
#define ICON_FA_CHECK_CIRCLE "\xef\x81\x98"
#define ICON_FA_CHECK_DOUBLE "\xef\x95\xa0"
#define ICON_FA_CHECK_SQUARE "\xef\x85\x8a"
#define ICON_FA_CHEESE "\xef\x9f\xaf"
#define ICON_FA_CHEESE_SWISS "\xef\x9f\xb0"
#define ICON_FA_CHEESEBURGER "\xef\x9f\xb1"
#define ICON_FA_CHESS "\xef\x90\xb9"
#define ICON_FA_CHESS_BISHOP "\xef\x90\xba"
#define ICON_FA_CHESS_BISHOP_ALT "\xef\x90\xbb"
#define ICON_FA_CHESS_BOARD "\xef\x90\xbc"
#define ICON_FA_CHESS_CLOCK "\xef\x90\xbd"
#define ICON_FA_CHESS_CLOCK_ALT "\xef\x90\xbe"
#define ICON_FA_CHESS_KING "\xef\x90\xbf"
#define ICON_FA_CHESS_KING_ALT "\xef\x91\x80"
#define ICON_FA_CHESS_KNIGHT "\xef\x91\x81"
#define ICON_FA_CHESS_KNIGHT_ALT "\xef\x91\x82"
#define ICON_FA_CHESS_PAWN "\xef\x91\x83"
#define ICON_FA_CHESS_PAWN_ALT "\xef\x91\x84"
#define ICON_FA_CHESS_QUEEN "\xef\x91\x85"
#define ICON_FA_CHESS_QUEEN_ALT "\xef\x91\x86"
#define ICON_FA_CHESS_ROOK "\xef\x91\x87"
#define ICON_FA_CHESS_ROOK_ALT "\xef\x91\x88"
#define ICON_FA_CHEVRON_CIRCLE_DOWN "\xef\x84\xba"
#define ICON_FA_CHEVRON_CIRCLE_LEFT "\xef\x84\xb7"
#define ICON_FA_CHEVRON_CIRCLE_RIGHT "\xef\x84\xb8"
#define ICON_FA_CHEVRON_CIRCLE_UP "\xef\x84\xb9"
#define ICON_FA_CHEVRON_DOUBLE_DOWN "\xef\x8c\xa2"
#define ICON_FA_CHEVRON_DOUBLE_LEFT "\xef\x8c\xa3"
#define ICON_FA_CHEVRON_DOUBLE_RIGHT "\xef\x8c\xa4"
#define ICON_FA_CHEVRON_DOUBLE_UP "\xef\x8c\xa5"
#define ICON_FA_CHEVRON_DOWN "\xef\x81\xb8"
#define ICON_FA_CHEVRON_LEFT "\xef\x81\x93"
#define ICON_FA_CHEVRON_RIGHT "\xef\x81\x94"
#define ICON_FA_CHEVRON_SQUARE_DOWN "\xef\x8c\xa9"
#define ICON_FA_CHEVRON_SQUARE_LEFT "\xef\x8c\xaa"
#define ICON_FA_CHEVRON_SQUARE_RIGHT "\xef\x8c\xab"
#define ICON_FA_CHEVRON_SQUARE_UP "\xef\x8c\xac"
#define ICON_FA_CHEVRON_UP "\xef\x81\xb7"
#define ICON_FA_CHILD "\xef\x86\xae"
#define ICON_FA_CHIMNEY "\xef\x9e\x8b"
#define ICON_FA_CHURCH "\xef\x94\x9d"
#define ICON_FA_CIRCLE "\xef\x84\x91"
#define ICON_FA_CIRCLE_NOTCH "\xef\x87\x8e"
#define ICON_FA_CITY "\xef\x99\x8f"
#define ICON_FA_CLARINET "\xef\xa2\xad"
#define ICON_FA_CLAW_MARKS "\xef\x9b\x82"
#define ICON_FA_CLINIC_MEDICAL "\xef\x9f\xb2"
#define ICON_FA_CLIPBOARD "\xef\x8c\xa8"
#define ICON_FA_CLIPBOARD_CHECK "\xef\x91\xac"
#define ICON_FA_CLIPBOARD_LIST "\xef\x91\xad"
#define ICON_FA_CLIPBOARD_LIST_CHECK "\xef\x9c\xb7"
#define ICON_FA_CLIPBOARD_PRESCRIPTION "\xef\x97\xa8"
#define ICON_FA_CLIPBOARD_USER "\xef\x9f\xb3"
#define ICON_FA_CLOCK "\xef\x80\x97"
#define ICON_FA_CLONE "\xef\x89\x8d"
#define ICON_FA_CLOSED_CAPTIONING "\xef\x88\x8a"
#define ICON_FA_CLOUD "\xef\x83\x82"
#define ICON_FA_CLOUD_DOWNLOAD "\xef\x83\xad"
#define ICON_FA_CLOUD_DOWNLOAD_ALT "\xef\x8e\x81"
#define ICON_FA_CLOUD_DRIZZLE "\xef\x9c\xb8"
#define ICON_FA_CLOUD_HAIL "\xef\x9c\xb9"
#define ICON_FA_CLOUD_HAIL_MIXED "\xef\x9c\xba"
#define ICON_FA_CLOUD_MEATBALL "\xef\x9c\xbb"
#define ICON_FA_CLOUD_MOON "\xef\x9b\x83"
#define ICON_FA_CLOUD_MOON_RAIN "\xef\x9c\xbc"
#define ICON_FA_CLOUD_MUSIC "\xef\xa2\xae"
#define ICON_FA_CLOUD_RAIN "\xef\x9c\xbd"
#define ICON_FA_CLOUD_RAINBOW "\xef\x9c\xbe"
#define ICON_FA_CLOUD_SHOWERS "\xef\x9c\xbf"
#define ICON_FA_CLOUD_SHOWERS_HEAVY "\xef\x9d\x80"
#define ICON_FA_CLOUD_SLEET "\xef\x9d\x81"
#define ICON_FA_CLOUD_SNOW "\xef\x9d\x82"
#define ICON_FA_CLOUD_SUN "\xef\x9b\x84"
#define ICON_FA_CLOUD_SUN_RAIN "\xef\x9d\x83"
#define ICON_FA_CLOUD_UPLOAD "\xef\x83\xae"
#define ICON_FA_CLOUD_UPLOAD_ALT "\xef\x8e\x82"
#define ICON_FA_CLOUDS "\xef\x9d\x84"
#define ICON_FA_CLOUDS_MOON "\xef\x9d\x85"
#define ICON_FA_CLOUDS_SUN "\xef\x9d\x86"
#define ICON_FA_CLUB "\xef\x8c\xa7"
#define ICON_FA_COCKTAIL "\xef\x95\xa1"
#define ICON_FA_CODE "\xef\x84\xa1"
#define ICON_FA_CODE_BRANCH "\xef\x84\xa6"
#define ICON_FA_CODE_COMMIT "\xef\x8e\x86"
#define ICON_FA_CODE_MERGE "\xef\x8e\x87"
#define ICON_FA_COFFEE "\xef\x83\xb4"
#define ICON_FA_COFFEE_POT "\xee\x80\x82"
#define ICON_FA_COFFEE_TOGO "\xef\x9b\x85"
#define ICON_FA_COFFIN "\xef\x9b\x86"
#define ICON_FA_COFFIN_CROSS "\xee\x81\x91"
#define ICON_FA_COG "\xef\x80\x93"
#define ICON_FA_COGS "\xef\x82\x85"
#define ICON_FA_COIN "\xef\xa1\x9c"
#define ICON_FA_COINS "\xef\x94\x9e"
#define ICON_FA_COLUMNS "\xef\x83\x9b"
#define ICON_FA_COMET "\xee\x80\x83"
#define ICON_FA_COMMENT "\xef\x81\xb5"
#define ICON_FA_COMMENT_ALT "\xef\x89\xba"
#define ICON_FA_COMMENT_ALT_CHECK "\xef\x92\xa2"
#define ICON_FA_COMMENT_ALT_DOLLAR "\xef\x99\x90"
#define ICON_FA_COMMENT_ALT_DOTS "\xef\x92\xa3"
#define ICON_FA_COMMENT_ALT_EDIT "\xef\x92\xa4"
#define ICON_FA_COMMENT_ALT_EXCLAMATION "\xef\x92\xa5"
#define ICON_FA_COMMENT_ALT_LINES "\xef\x92\xa6"
#define ICON_FA_COMMENT_ALT_MEDICAL "\xef\x9f\xb4"
#define ICON_FA_COMMENT_ALT_MINUS "\xef\x92\xa7"
#define ICON_FA_COMMENT_ALT_MUSIC "\xef\xa2\xaf"
#define ICON_FA_COMMENT_ALT_PLUS "\xef\x92\xa8"
#define ICON_FA_COMMENT_ALT_SLASH "\xef\x92\xa9"
#define ICON_FA_COMMENT_ALT_SMILE "\xef\x92\xaa"
#define ICON_FA_COMMENT_ALT_TIMES "\xef\x92\xab"
#define ICON_FA_COMMENT_CHECK "\xef\x92\xac"
#define ICON_FA_COMMENT_DOLLAR "\xef\x99\x91"
#define ICON_FA_COMMENT_DOTS "\xef\x92\xad"
#define ICON_FA_COMMENT_EDIT "\xef\x92\xae"
#define ICON_FA_COMMENT_EXCLAMATION "\xef\x92\xaf"
#define ICON_FA_COMMENT_LINES "\xef\x92\xb0"
#define ICON_FA_COMMENT_MEDICAL "\xef\x9f\xb5"
#define ICON_FA_COMMENT_MINUS "\xef\x92\xb1"
#define ICON_FA_COMMENT_MUSIC "\xef\xa2\xb0"
#define ICON_FA_COMMENT_PLUS "\xef\x92\xb2"
#define ICON_FA_COMMENT_SLASH "\xef\x92\xb3"
#define ICON_FA_COMMENT_SMILE "\xef\x92\xb4"
#define ICON_FA_COMMENT_TIMES "\xef\x92\xb5"
#define ICON_FA_COMMENTS "\xef\x82\x86"
#define ICON_FA_COMMENTS_ALT "\xef\x92\xb6"
#define ICON_FA_COMMENTS_ALT_DOLLAR "\xef\x99\x92"
#define ICON_FA_COMMENTS_DOLLAR "\xef\x99\x93"
#define ICON_FA_COMPACT_DISC "\xef\x94\x9f"
#define ICON_FA_COMPASS "\xef\x85\x8e"
#define ICON_FA_COMPASS_SLASH "\xef\x97\xa9"
#define ICON_FA_COMPRESS "\xef\x81\xa6"
#define ICON_FA_COMPRESS_ALT "\xef\x90\xa2"
#define ICON_FA_COMPRESS_ARROWS_ALT "\xef\x9e\x8c"
#define ICON_FA_COMPRESS_WIDE "\xef\x8c\xa6"
#define ICON_FA_COMPUTER_CLASSIC "\xef\xa2\xb1"
#define ICON_FA_COMPUTER_SPEAKER "\xef\xa2\xb2"
#define ICON_FA_CONCIERGE_BELL "\xef\x95\xa2"
#define ICON_FA_CONSTRUCTION "\xef\xa1\x9d"
#define ICON_FA_CONTAINER_STORAGE "\xef\x92\xb7"
#define ICON_FA_CONVEYOR_BELT "\xef\x91\xae"
#define ICON_FA_CONVEYOR_BELT_ALT "\xef\x91\xaf"
#define ICON_FA_COOKIE "\xef\x95\xa3"
#define ICON_FA_COOKIE_BITE "\xef\x95\xa4"
#define ICON_FA_COPY "\xef\x83\x85"
#define ICON_FA_COPYRIGHT "\xef\x87\xb9"
#define ICON_FA_CORN "\xef\x9b\x87"
#define ICON_FA_COUCH "\xef\x92\xb8"
#define ICON_FA_COW "\xef\x9b\x88"
#define ICON_FA_COWBELL "\xef\xa2\xb3"
#define ICON_FA_COWBELL_MORE "\xef\xa2\xb4"
#define ICON_FA_CREDIT_CARD "\xef\x82\x9d"
#define ICON_FA_CREDIT_CARD_BLANK "\xef\x8e\x89"
#define ICON_FA_CREDIT_CARD_FRONT "\xef\x8e\x8a"
#define ICON_FA_CRICKET "\xef\x91\x89"
#define ICON_FA_CROISSANT "\xef\x9f\xb6"
#define ICON_FA_CROP "\xef\x84\xa5"
#define ICON_FA_CROP_ALT "\xef\x95\xa5"
#define ICON_FA_CROSS "\xef\x99\x94"
#define ICON_FA_CROSSHAIRS "\xef\x81\x9b"
#define ICON_FA_CROW "\xef\x94\xa0"
#define ICON_FA_CROWN "\xef\x94\xa1"
#define ICON_FA_CRUTCH "\xef\x9f\xb7"
#define ICON_FA_CRUTCHES "\xef\x9f\xb8"
#define ICON_FA_CUBE "\xef\x86\xb2"
#define ICON_FA_CUBES "\xef\x86\xb3"
#define ICON_FA_CURLING "\xef\x91\x8a"
#define ICON_FA_CUT "\xef\x83\x84"
#define ICON_FA_DAGGER "\xef\x9b\x8b"
#define ICON_FA_DATABASE "\xef\x87\x80"
#define ICON_FA_DEAF "\xef\x8a\xa4"
#define ICON_FA_DEBUG "\xef\x9f\xb9"
#define ICON_FA_DEER "\xef\x9e\x8e"
#define ICON_FA_DEER_RUDOLPH "\xef\x9e\x8f"
#define ICON_FA_DEMOCRAT "\xef\x9d\x87"
#define ICON_FA_DESKTOP "\xef\x84\x88"
#define ICON_FA_DESKTOP_ALT "\xef\x8e\x90"
#define ICON_FA_DEWPOINT "\xef\x9d\x88"
#define ICON_FA_DHARMACHAKRA "\xef\x99\x95"
#define ICON_FA_DIAGNOSES "\xef\x91\xb0"
#define ICON_FA_DIAMOND "\xef\x88\x99"
#define ICON_FA_DICE "\xef\x94\xa2"
#define ICON_FA_DICE_D10 "\xef\x9b\x8d"
#define ICON_FA_DICE_D12 "\xef\x9b\x8e"
#define ICON_FA_DICE_D20 "\xef\x9b\x8f"
#define ICON_FA_DICE_D4 "\xef\x9b\x90"
#define ICON_FA_DICE_D6 "\xef\x9b\x91"
#define ICON_FA_DICE_D8 "\xef\x9b\x92"
#define ICON_FA_DICE_FIVE "\xef\x94\xa3"
#define ICON_FA_DICE_FOUR "\xef\x94\xa4"
#define ICON_FA_DICE_ONE "\xef\x94\xa5"
#define ICON_FA_DICE_SIX "\xef\x94\xa6"
#define ICON_FA_DICE_THREE "\xef\x94\xa7"
#define ICON_FA_DICE_TWO "\xef\x94\xa8"
#define ICON_FA_DIGGING "\xef\xa1\x9e"
#define ICON_FA_DIGITAL_TACHOGRAPH "\xef\x95\xa6"
#define ICON_FA_DIPLOMA "\xef\x97\xaa"
#define ICON_FA_DIRECTIONS "\xef\x97\xab"
#define ICON_FA_DISC_DRIVE "\xef\xa2\xb5"
#define ICON_FA_DISEASE "\xef\x9f\xba"
#define ICON_FA_DIVIDE "\xef\x94\xa9"
#define ICON_FA_DIZZY "\xef\x95\xa7"
#define ICON_FA_DNA "\xef\x91\xb1"
#define ICON_FA_DO_NOT_ENTER "\xef\x97\xac"
#define ICON_FA_DOG "\xef\x9b\x93"
#define ICON_FA_DOG_LEASHED "\xef\x9b\x94"
#define ICON_FA_DOLLAR_SIGN "\xef\x85\x95"
#define ICON_FA_DOLLY "\xef\x91\xb2"
#define ICON_FA_DOLLY_EMPTY "\xef\x91\xb3"
#define ICON_FA_DOLLY_FLATBED "\xef\x91\xb4"
#define ICON_FA_DOLLY_FLATBED_ALT "\xef\x91\xb5"
#define ICON_FA_DOLLY_FLATBED_EMPTY "\xef\x91\xb6"
#define ICON_FA_DONATE "\xef\x92\xb9"
#define ICON_FA_DOOR_CLOSED "\xef\x94\xaa"
#define ICON_FA_DOOR_OPEN "\xef\x94\xab"
#define ICON_FA_DOT_CIRCLE "\xef\x86\x92"
#define ICON_FA_DOVE "\xef\x92\xba"
#define ICON_FA_DOWNLOAD "\xef\x80\x99"
#define ICON_FA_DRAFTING_COMPASS "\xef\x95\xa8"
#define ICON_FA_DRAGON "\xef\x9b\x95"
#define ICON_FA_DRAW_CIRCLE "\xef\x97\xad"
#define ICON_FA_DRAW_POLYGON "\xef\x97\xae"
#define ICON_FA_DRAW_SQUARE "\xef\x97\xaf"
#define ICON_FA_DREIDEL "\xef\x9e\x92"
#define ICON_FA_DRONE "\xef\xa1\x9f"
#define ICON_FA_DRONE_ALT "\xef\xa1\xa0"
#define ICON_FA_DRUM "\xef\x95\xa9"
#define ICON_FA_DRUM_STEELPAN "\xef\x95\xaa"
#define ICON_FA_DRUMSTICK "\xef\x9b\x96"
#define ICON_FA_DRUMSTICK_BITE "\xef\x9b\x97"
#define ICON_FA_DRYER "\xef\xa1\xa1"
#define ICON_FA_DRYER_ALT "\xef\xa1\xa2"
#define ICON_FA_DUCK "\xef\x9b\x98"
#define ICON_FA_DUMBBELL "\xef\x91\x8b"
#define ICON_FA_DUMPSTER "\xef\x9e\x93"
#define ICON_FA_DUMPSTER_FIRE "\xef\x9e\x94"
#define ICON_FA_DUNGEON "\xef\x9b\x99"
#define ICON_FA_EAR "\xef\x97\xb0"
#define ICON_FA_EAR_MUFFS "\xef\x9e\x95"
#define ICON_FA_ECLIPSE "\xef\x9d\x89"
#define ICON_FA_ECLIPSE_ALT "\xef\x9d\x8a"
#define ICON_FA_EDIT "\xef\x81\x84"
#define ICON_FA_EGG "\xef\x9f\xbb"
#define ICON_FA_EGG_FRIED "\xef\x9f\xbc"
#define ICON_FA_EJECT "\xef\x81\x92"
#define ICON_FA_ELEPHANT "\xef\x9b\x9a"
#define ICON_FA_ELLIPSIS_H "\xef\x85\x81"
#define ICON_FA_ELLIPSIS_H_ALT "\xef\x8e\x9b"
#define ICON_FA_ELLIPSIS_V "\xef\x85\x82"
#define ICON_FA_ELLIPSIS_V_ALT "\xef\x8e\x9c"
#define ICON_FA_EMPTY_SET "\xef\x99\x96"
#define ICON_FA_ENGINE_WARNING "\xef\x97\xb2"
#define ICON_FA_ENVELOPE "\xef\x83\xa0"
#define ICON_FA_ENVELOPE_OPEN "\xef\x8a\xb6"
#define ICON_FA_ENVELOPE_OPEN_DOLLAR "\xef\x99\x97"
#define ICON_FA_ENVELOPE_OPEN_TEXT "\xef\x99\x98"
#define ICON_FA_ENVELOPE_SQUARE "\xef\x86\x99"
#define ICON_FA_EQUALS "\xef\x94\xac"
#define ICON_FA_ERASER "\xef\x84\xad"
#define ICON_FA_ETHERNET "\xef\x9e\x96"
#define ICON_FA_EURO_SIGN "\xef\x85\x93"
#define ICON_FA_EXCHANGE "\xef\x83\xac"
#define ICON_FA_EXCHANGE_ALT "\xef\x8d\xa2"
#define ICON_FA_EXCLAMATION "\xef\x84\xaa"
#define ICON_FA_EXCLAMATION_CIRCLE "\xef\x81\xaa"
#define ICON_FA_EXCLAMATION_SQUARE "\xef\x8c\xa1"
#define ICON_FA_EXCLAMATION_TRIANGLE "\xef\x81\xb1"
#define ICON_FA_EXPAND "\xef\x81\xa5"
#define ICON_FA_EXPAND_ALT "\xef\x90\xa4"
#define ICON_FA_EXPAND_ARROWS "\xef\x8c\x9d"
#define ICON_FA_EXPAND_ARROWS_ALT "\xef\x8c\x9e"
#define ICON_FA_EXPAND_WIDE "\xef\x8c\xa0"
#define ICON_FA_EXTERNAL_LINK "\xef\x82\x8e"
#define ICON_FA_EXTERNAL_LINK_ALT "\xef\x8d\x9d"
#define ICON_FA_EXTERNAL_LINK_SQUARE "\xef\x85\x8c"
#define ICON_FA_EXTERNAL_LINK_SQUARE_ALT "\xef\x8d\xa0"
#define ICON_FA_EYE "\xef\x81\xae"
#define ICON_FA_EYE_DROPPER "\xef\x87\xbb"
#define ICON_FA_EYE_EVIL "\xef\x9b\x9b"
#define ICON_FA_EYE_SLASH "\xef\x81\xb0"
#define ICON_FA_FAN "\xef\xa1\xa3"
#define ICON_FA_FAN_TABLE "\xee\x80\x84"
#define ICON_FA_FARM "\xef\xa1\xa4"
#define ICON_FA_FAST_BACKWARD "\xef\x81\x89"
#define ICON_FA_FAST_FORWARD "\xef\x81\x90"
#define ICON_FA_FAUCET "\xee\x80\x85"
#define ICON_FA_FAUCET_DRIP "\xee\x80\x86"
#define ICON_FA_FAX "\xef\x86\xac"
#define ICON_FA_FEATHER "\xef\x94\xad"
#define ICON_FA_FEATHER_ALT "\xef\x95\xab"
#define ICON_FA_FEMALE "\xef\x86\x82"
#define ICON_FA_FIELD_HOCKEY "\xef\x91\x8c"
#define ICON_FA_FIGHTER_JET "\xef\x83\xbb"
#define ICON_FA_FILE "\xef\x85\x9b"
#define ICON_FA_FILE_ALT "\xef\x85\x9c"
#define ICON_FA_FILE_ARCHIVE "\xef\x87\x86"
#define ICON_FA_FILE_AUDIO "\xef\x87\x87"
#define ICON_FA_FILE_CERTIFICATE "\xef\x97\xb3"
#define ICON_FA_FILE_CHART_LINE "\xef\x99\x99"
#define ICON_FA_FILE_CHART_PIE "\xef\x99\x9a"
#define ICON_FA_FILE_CHECK "\xef\x8c\x96"
#define ICON_FA_FILE_CODE "\xef\x87\x89"
#define ICON_FA_FILE_CONTRACT "\xef\x95\xac"
#define ICON_FA_FILE_CSV "\xef\x9b\x9d"
#define ICON_FA_FILE_DOWNLOAD "\xef\x95\xad"
#define ICON_FA_FILE_EDIT "\xef\x8c\x9c"
#define ICON_FA_FILE_EXCEL "\xef\x87\x83"
#define ICON_FA_FILE_EXCLAMATION "\xef\x8c\x9a"
#define ICON_FA_FILE_EXPORT "\xef\x95\xae"
#define ICON_FA_FILE_IMAGE "\xef\x87\x85"
#define ICON_FA_FILE_IMPORT "\xef\x95\xaf"
#define ICON_FA_FILE_INVOICE "\xef\x95\xb0"
#define ICON_FA_FILE_INVOICE_DOLLAR "\xef\x95\xb1"
#define ICON_FA_FILE_MEDICAL "\xef\x91\xb7"
#define ICON_FA_FILE_MEDICAL_ALT "\xef\x91\xb8"
#define ICON_FA_FILE_MINUS "\xef\x8c\x98"
#define ICON_FA_FILE_MUSIC "\xef\xa2\xb6"
#define ICON_FA_FILE_PDF "\xef\x87\x81"
#define ICON_FA_FILE_PLUS "\xef\x8c\x99"
#define ICON_FA_FILE_POWERPOINT "\xef\x87\x84"
#define ICON_FA_FILE_PRESCRIPTION "\xef\x95\xb2"
#define ICON_FA_FILE_SEARCH "\xef\xa1\xa5"
#define ICON_FA_FILE_SIGNATURE "\xef\x95\xb3"
#define ICON_FA_FILE_SPREADSHEET "\xef\x99\x9b"
#define ICON_FA_FILE_TIMES "\xef\x8c\x97"
#define ICON_FA_FILE_UPLOAD "\xef\x95\xb4"
#define ICON_FA_FILE_USER "\xef\x99\x9c"
#define ICON_FA_FILE_VIDEO "\xef\x87\x88"
#define ICON_FA_FILE_WORD "\xef\x87\x82"
#define ICON_FA_FILES_MEDICAL "\xef\x9f\xbd"
#define ICON_FA_FILL "\xef\x95\xb5"
#define ICON_FA_FILL_DRIP "\xef\x95\xb6"
#define ICON_FA_FILM "\xef\x80\x88"
#define ICON_FA_FILM_ALT "\xef\x8e\xa0"
#define ICON_FA_FILM_CANISTER "\xef\xa2\xb7"
#define ICON_FA_FILTER "\xef\x82\xb0"
#define ICON_FA_FINGERPRINT "\xef\x95\xb7"
#define ICON_FA_FIRE "\xef\x81\xad"
#define ICON_FA_FIRE_ALT "\xef\x9f\xa4"
#define ICON_FA_FIRE_EXTINGUISHER "\xef\x84\xb4"
#define ICON_FA_FIRE_SMOKE "\xef\x9d\x8b"
#define ICON_FA_FIREPLACE "\xef\x9e\x9a"
#define ICON_FA_FIRST_AID "\xef\x91\xb9"
#define ICON_FA_FISH "\xef\x95\xb8"
#define ICON_FA_FISH_COOKED "\xef\x9f\xbe"
#define ICON_FA_FIST_RAISED "\xef\x9b\x9e"
#define ICON_FA_FLAG "\xef\x80\xa4"
#define ICON_FA_FLAG_ALT "\xef\x9d\x8c"
#define ICON_FA_FLAG_CHECKERED "\xef\x84\x9e"
#define ICON_FA_FLAG_USA "\xef\x9d\x8d"
#define ICON_FA_FLAME "\xef\x9b\x9f"
#define ICON_FA_FLASHLIGHT "\xef\xa2\xb8"
#define ICON_FA_FLASK "\xef\x83\x83"
#define ICON_FA_FLASK_POISON "\xef\x9b\xa0"
#define ICON_FA_FLASK_POTION "\xef\x9b\xa1"
#define ICON_FA_FLOWER "\xef\x9f\xbf"
#define ICON_FA_FLOWER_DAFFODIL "\xef\xa0\x80"
#define ICON_FA_FLOWER_TULIP "\xef\xa0\x81"
#define ICON_FA_FLUSHED "\xef\x95\xb9"
#define ICON_FA_FLUTE "\xef\xa2\xb9"
#define ICON_FA_FLUX_CAPACITOR "\xef\xa2\xba"
#define ICON_FA_FOG "\xef\x9d\x8e"
#define ICON_FA_FOLDER "\xef\x81\xbb"
#define ICON_FA_FOLDER_DOWNLOAD "\xee\x81\x93"
#define ICON_FA_FOLDER_MINUS "\xef\x99\x9d"
#define ICON_FA_FOLDER_OPEN "\xef\x81\xbc"
#define ICON_FA_FOLDER_PLUS "\xef\x99\x9e"
#define ICON_FA_FOLDER_TIMES "\xef\x99\x9f"
#define ICON_FA_FOLDER_TREE "\xef\xa0\x82"
#define ICON_FA_FOLDER_UPLOAD "\xee\x81\x94"
#define ICON_FA_FOLDERS "\xef\x99\xa0"
#define ICON_FA_FONT "\xef\x80\xb1"
#define ICON_FA_FONT_AWESOME_LOGO_FULL "\xef\x93\xa6"
#define ICON_FA_FONT_CASE "\xef\xa1\xa6"
#define ICON_FA_FOOTBALL_BALL "\xef\x91\x8e"
#define ICON_FA_FOOTBALL_HELMET "\xef\x91\x8f"
#define ICON_FA_FORKLIFT "\xef\x91\xba"
#define ICON_FA_FORWARD "\xef\x81\x8e"
#define ICON_FA_FRAGILE "\xef\x92\xbb"
#define ICON_FA_FRENCH_FRIES "\xef\xa0\x83"
#define ICON_FA_FROG "\xef\x94\xae"
#define ICON_FA_FROSTY_HEAD "\xef\x9e\x9b"
#define ICON_FA_FROWN "\xef\x84\x99"
#define ICON_FA_FROWN_OPEN "\xef\x95\xba"
#define ICON_FA_FUNCTION "\xef\x99\xa1"
#define ICON_FA_FUNNEL_DOLLAR "\xef\x99\xa2"
#define ICON_FA_FUTBOL "\xef\x87\xa3"
#define ICON_FA_GALAXY "\xee\x80\x88"
#define ICON_FA_GAME_BOARD "\xef\xa1\xa7"
#define ICON_FA_GAME_BOARD_ALT "\xef\xa1\xa8"
#define ICON_FA_GAME_CONSOLE_HANDHELD "\xef\xa2\xbb"
#define ICON_FA_GAMEPAD "\xef\x84\x9b"
#define ICON_FA_GAMEPAD_ALT "\xef\xa2\xbc"
#define ICON_FA_GARAGE "\xee\x80\x89"
#define ICON_FA_GARAGE_CAR "\xee\x80\x8a"
#define ICON_FA_GARAGE_OPEN "\xee\x80\x8b"
#define ICON_FA_GAS_PUMP "\xef\x94\xaf"
#define ICON_FA_GAS_PUMP_SLASH "\xef\x97\xb4"
#define ICON_FA_GAVEL "\xef\x83\xa3"
#define ICON_FA_GEM "\xef\x8e\xa5"
#define ICON_FA_GENDERLESS "\xef\x88\xad"
#define ICON_FA_GHOST "\xef\x9b\xa2"
#define ICON_FA_GIFT "\xef\x81\xab"
#define ICON_FA_GIFT_CARD "\xef\x99\xa3"
#define ICON_FA_GIFTS "\xef\x9e\x9c"
#define ICON_FA_GINGERBREAD_MAN "\xef\x9e\x9d"
#define ICON_FA_GLASS "\xef\xa0\x84"
#define ICON_FA_GLASS_CHAMPAGNE "\xef\x9e\x9e"
#define ICON_FA_GLASS_CHEERS "\xef\x9e\x9f"
#define ICON_FA_GLASS_CITRUS "\xef\xa1\xa9"
#define ICON_FA_GLASS_MARTINI "\xef\x80\x80"
#define ICON_FA_GLASS_MARTINI_ALT "\xef\x95\xbb"
#define ICON_FA_GLASS_WHISKEY "\xef\x9e\xa0"
#define ICON_FA_GLASS_WHISKEY_ROCKS "\xef\x9e\xa1"
#define ICON_FA_GLASSES "\xef\x94\xb0"
#define ICON_FA_GLASSES_ALT "\xef\x97\xb5"
#define ICON_FA_GLOBE "\xef\x82\xac"
#define ICON_FA_GLOBE_AFRICA "\xef\x95\xbc"
#define ICON_FA_GLOBE_AMERICAS "\xef\x95\xbd"
#define ICON_FA_GLOBE_ASIA "\xef\x95\xbe"
#define ICON_FA_GLOBE_EUROPE "\xef\x9e\xa2"
#define ICON_FA_GLOBE_SNOW "\xef\x9e\xa3"
#define ICON_FA_GLOBE_STAND "\xef\x97\xb6"
#define ICON_FA_GOLF_BALL "\xef\x91\x90"
#define ICON_FA_GOLF_CLUB "\xef\x91\x91"
#define ICON_FA_GOPURAM "\xef\x99\xa4"
#define ICON_FA_GRADUATION_CAP "\xef\x86\x9d"
#define ICON_FA_GRAMOPHONE "\xef\xa2\xbd"
#define ICON_FA_GREATER_THAN "\xef\x94\xb1"
#define ICON_FA_GREATER_THAN_EQUAL "\xef\x94\xb2"
#define ICON_FA_GRIMACE "\xef\x95\xbf"
#define ICON_FA_GRIN "\xef\x96\x80"
#define ICON_FA_GRIN_ALT "\xef\x96\x81"
#define ICON_FA_GRIN_BEAM "\xef\x96\x82"
#define ICON_FA_GRIN_BEAM_SWEAT "\xef\x96\x83"
#define ICON_FA_GRIN_HEARTS "\xef\x96\x84"
#define ICON_FA_GRIN_SQUINT "\xef\x96\x85"
#define ICON_FA_GRIN_SQUINT_TEARS "\xef\x96\x86"
#define ICON_FA_GRIN_STARS "\xef\x96\x87"
#define ICON_FA_GRIN_TEARS "\xef\x96\x88"
#define ICON_FA_GRIN_TONGUE "\xef\x96\x89"
#define ICON_FA_GRIN_TONGUE_SQUINT "\xef\x96\x8a"
#define ICON_FA_GRIN_TONGUE_WINK "\xef\x96\x8b"
#define ICON_FA_GRIN_WINK "\xef\x96\x8c"
#define ICON_FA_GRIP_HORIZONTAL "\xef\x96\x8d"
#define ICON_FA_GRIP_LINES "\xef\x9e\xa4"
#define ICON_FA_GRIP_LINES_VERTICAL "\xef\x9e\xa5"
#define ICON_FA_GRIP_VERTICAL "\xef\x96\x8e"
#define ICON_FA_GUITAR "\xef\x9e\xa6"
#define ICON_FA_GUITAR_ELECTRIC "\xef\xa2\xbe"
#define ICON_FA_GUITARS "\xef\xa2\xbf"
#define ICON_FA_H_SQUARE "\xef\x83\xbd"
#define ICON_FA_H1 "\xef\x8c\x93"
#define ICON_FA_H2 "\xef\x8c\x94"
#define ICON_FA_H3 "\xef\x8c\x95"
#define ICON_FA_H4 "\xef\xa1\xaa"
#define ICON_FA_HAMBURGER "\xef\xa0\x85"
#define ICON_FA_HAMMER "\xef\x9b\xa3"
#define ICON_FA_HAMMER_WAR "\xef\x9b\xa4"
#define ICON_FA_HAMSA "\xef\x99\xa5"
#define ICON_FA_HAND_HEART "\xef\x92\xbc"
#define ICON_FA_HAND_HOLDING "\xef\x92\xbd"
#define ICON_FA_HAND_HOLDING_BOX "\xef\x91\xbb"
#define ICON_FA_HAND_HOLDING_HEART "\xef\x92\xbe"
#define ICON_FA_HAND_HOLDING_MAGIC "\xef\x9b\xa5"
#define ICON_FA_HAND_HOLDING_MEDICAL "\xee\x81\x9c"
#define ICON_FA_HAND_HOLDING_SEEDLING "\xef\x92\xbf"
#define ICON_FA_HAND_HOLDING_USD "\xef\x93\x80"
#define ICON_FA_HAND_HOLDING_WATER "\xef\x93\x81"
#define ICON_FA_HAND_LIZARD "\xef\x89\x98"
#define ICON_FA_HAND_MIDDLE_FINGER "\xef\xa0\x86"
#define ICON_FA_HAND_PAPER "\xef\x89\x96"
#define ICON_FA_HAND_PEACE "\xef\x89\x9b"
#define ICON_FA_HAND_POINT_DOWN "\xef\x82\xa7"
#define ICON_FA_HAND_POINT_LEFT "\xef\x82\xa5"
#define ICON_FA_HAND_POINT_RIGHT "\xef\x82\xa4"
#define ICON_FA_HAND_POINT_UP "\xef\x82\xa6"
#define ICON_FA_HAND_POINTER "\xef\x89\x9a"
#define ICON_FA_HAND_RECEIVING "\xef\x91\xbc"
#define ICON_FA_HAND_ROCK "\xef\x89\x95"
#define ICON_FA_HAND_SCISSORS "\xef\x89\x97"
#define ICON_FA_HAND_SPARKLES "\xee\x81\x9d"
#define ICON_FA_HAND_SPOCK "\xef\x89\x99"
#define ICON_FA_HANDS "\xef\x93\x82"
#define ICON_FA_HANDS_HEART "\xef\x93\x83"
#define ICON_FA_HANDS_HELPING "\xef\x93\x84"
#define ICON_FA_HANDS_USD "\xef\x93\x85"
#define ICON_FA_HANDS_WASH "\xee\x81\x9e"
#define ICON_FA_HANDSHAKE "\xef\x8a\xb5"
#define ICON_FA_HANDSHAKE_ALT "\xef\x93\x86"
#define ICON_FA_HANDSHAKE_ALT_SLASH "\xee\x81\x9f"
#define ICON_FA_HANDSHAKE_SLASH "\xee\x81\xa0"
#define ICON_FA_HANUKIAH "\xef\x9b\xa6"
#define ICON_FA_HARD_HAT "\xef\xa0\x87"
#define ICON_FA_HASHTAG "\xef\x8a\x92"
#define ICON_FA_HAT_CHEF "\xef\xa1\xab"
#define ICON_FA_HAT_COWBOY "\xef\xa3\x80"
#define ICON_FA_HAT_COWBOY_SIDE "\xef\xa3\x81"
#define ICON_FA_HAT_SANTA "\xef\x9e\xa7"
#define ICON_FA_HAT_WINTER "\xef\x9e\xa8"
#define ICON_FA_HAT_WITCH "\xef\x9b\xa7"
#define ICON_FA_HAT_WIZARD "\xef\x9b\xa8"
#define ICON_FA_HDD "\xef\x82\xa0"
#define ICON_FA_HEAD_SIDE "\xef\x9b\xa9"
#define ICON_FA_HEAD_SIDE_BRAIN "\xef\xa0\x88"
#define ICON_FA_HEAD_SIDE_COUGH "\xee\x81\xa1"
#define ICON_FA_HEAD_SIDE_COUGH_SLASH "\xee\x81\xa2"
#define ICON_FA_HEAD_SIDE_HEADPHONES "\xef\xa3\x82"
#define ICON_FA_HEAD_SIDE_MASK "\xee\x81\xa3"
#define ICON_FA_HEAD_SIDE_MEDICAL "\xef\xa0\x89"
#define ICON_FA_HEAD_SIDE_VIRUS "\xee\x81\xa4"
#define ICON_FA_HEAD_VR "\xef\x9b\xaa"
#define ICON_FA_HEADING "\xef\x87\x9c"
#define ICON_FA_HEADPHONES "\xef\x80\xa5"
#define ICON_FA_HEADPHONES_ALT "\xef\x96\x8f"
#define ICON_FA_HEADSET "\xef\x96\x90"
#define ICON_FA_HEART "\xef\x80\x84"
#define ICON_FA_HEART_BROKEN "\xef\x9e\xa9"
#define ICON_FA_HEART_CIRCLE "\xef\x93\x87"
#define ICON_FA_HEART_RATE "\xef\x97\xb8"
#define ICON_FA_HEART_SQUARE "\xef\x93\x88"
#define ICON_FA_HEARTBEAT "\xef\x88\x9e"
#define ICON_FA_HEAT "\xee\x80\x8c"
#define ICON_FA_HELICOPTER "\xef\x94\xb3"
#define ICON_FA_HELMET_BATTLE "\xef\x9b\xab"
#define ICON_FA_HEXAGON "\xef\x8c\x92"
#define ICON_FA_HIGHLIGHTER "\xef\x96\x91"
#define ICON_FA_HIKING "\xef\x9b\xac"
#define ICON_FA_HIPPO "\xef\x9b\xad"
#define ICON_FA_HISTORY "\xef\x87\x9a"
#define ICON_FA_HOCKEY_MASK "\xef\x9b\xae"
#define ICON_FA_HOCKEY_PUCK "\xef\x91\x93"
#define ICON_FA_HOCKEY_STICKS "\xef\x91\x94"
#define ICON_FA_HOLLY_BERRY "\xef\x9e\xaa"
#define ICON_FA_HOME "\xef\x80\x95"
#define ICON_FA_HOME_ALT "\xef\xa0\x8a"
#define ICON_FA_HOME_HEART "\xef\x93\x89"
#define ICON_FA_HOME_LG "\xef\xa0\x8b"
#define ICON_FA_HOME_LG_ALT "\xef\xa0\x8c"
#define ICON_FA_HOOD_CLOAK "\xef\x9b\xaf"
#define ICON_FA_HORIZONTAL_RULE "\xef\xa1\xac"
#define ICON_FA_HORSE "\xef\x9b\xb0"
#define ICON_FA_HORSE_HEAD "\xef\x9e\xab"
#define ICON_FA_HORSE_SADDLE "\xef\xa3\x83"
#define ICON_FA_HOSPITAL "\xef\x83\xb8"
#define ICON_FA_HOSPITAL_ALT "\xef\x91\xbd"
#define ICON_FA_HOSPITAL_SYMBOL "\xef\x91\xbe"
#define ICON_FA_HOSPITAL_USER "\xef\xa0\x8d"
#define ICON_FA_HOSPITALS "\xef\xa0\x8e"
#define ICON_FA_HOT_TUB "\xef\x96\x93"
#define ICON_FA_HOTDOG "\xef\xa0\x8f"
#define ICON_FA_HOTEL "\xef\x96\x94"
#define ICON_FA_HOURGLASS "\xef\x89\x94"
#define ICON_FA_HOURGLASS_END "\xef\x89\x93"
#define ICON_FA_HOURGLASS_HALF "\xef\x89\x92"
#define ICON_FA_HOURGLASS_START "\xef\x89\x91"
#define ICON_FA_HOUSE "\xee\x80\x8d"
#define ICON_FA_HOUSE_DAMAGE "\xef\x9b\xb1"
#define ICON_FA_HOUSE_DAY "\xee\x80\x8e"
#define ICON_FA_HOUSE_FLOOD "\xef\x9d\x8f"
#define ICON_FA_HOUSE_LEAVE "\xee\x80\x8f"
#define ICON_FA_HOUSE_NIGHT "\xee\x80\x90"
#define ICON_FA_HOUSE_RETURN "\xee\x80\x91"
#define ICON_FA_HOUSE_SIGNAL "\xee\x80\x92"
#define ICON_FA_HOUSE_USER "\xee\x81\xa5"
#define ICON_FA_HRYVNIA "\xef\x9b\xb2"
#define ICON_FA_HUMIDITY "\xef\x9d\x90"
#define ICON_FA_HURRICANE "\xef\x9d\x91"
#define ICON_FA_I_CURSOR "\xef\x89\x86"
#define ICON_FA_ICE_CREAM "\xef\xa0\x90"
#define ICON_FA_ICE_SKATE "\xef\x9e\xac"
#define ICON_FA_ICICLES "\xef\x9e\xad"
#define ICON_FA_ICONS "\xef\xa1\xad"
#define ICON_FA_ICONS_ALT "\xef\xa1\xae"
#define ICON_FA_ID_BADGE "\xef\x8b\x81"
#define ICON_FA_ID_CARD "\xef\x8b\x82"
#define ICON_FA_ID_CARD_ALT "\xef\x91\xbf"
#define ICON_FA_IGLOO "\xef\x9e\xae"
#define ICON_FA_IMAGE "\xef\x80\xbe"
#define ICON_FA_IMAGE_POLAROID "\xef\xa3\x84"
#define ICON_FA_IMAGES "\xef\x8c\x82"
#define ICON_FA_INBOX "\xef\x80\x9c"
#define ICON_FA_INBOX_IN "\xef\x8c\x90"
#define ICON_FA_INBOX_OUT "\xef\x8c\x91"
#define ICON_FA_INDENT "\xef\x80\xbc"
#define ICON_FA_INDUSTRY "\xef\x89\xb5"
#define ICON_FA_INDUSTRY_ALT "\xef\x8e\xb3"
#define ICON_FA_INFINITY "\xef\x94\xb4"
#define ICON_FA_INFO "\xef\x84\xa9"
#define ICON_FA_INFO_CIRCLE "\xef\x81\x9a"
#define ICON_FA_INFO_SQUARE "\xef\x8c\x8f"
#define ICON_FA_INHALER "\xef\x97\xb9"
#define ICON_FA_INTEGRAL "\xef\x99\xa7"
#define ICON_FA_INTERSECTION "\xef\x99\xa8"
#define ICON_FA_INVENTORY "\xef\x92\x80"
#define ICON_FA_ISLAND_TROPICAL "\xef\xa0\x91"
#define ICON_FA_ITALIC "\xef\x80\xb3"
#define ICON_FA_JACK_O_LANTERN "\xef\x8c\x8e"
#define ICON_FA_JEDI "\xef\x99\xa9"
#define ICON_FA_JOINT "\xef\x96\x95"
#define ICON_FA_JOURNAL_WHILLS "\xef\x99\xaa"
#define ICON_FA_JOYSTICK "\xef\xa3\x85"
#define ICON_FA_JUG "\xef\xa3\x86"
#define ICON_FA_KAABA "\xef\x99\xab"
#define ICON_FA_KAZOO "\xef\xa3\x87"
#define ICON_FA_KERNING "\xef\xa1\xaf"
#define ICON_FA_KEY "\xef\x82\x84"
#define ICON_FA_KEY_SKELETON "\xef\x9b\xb3"
#define ICON_FA_KEYBOARD "\xef\x84\x9c"
#define ICON_FA_KEYNOTE "\xef\x99\xac"
#define ICON_FA_KHANDA "\xef\x99\xad"
#define ICON_FA_KIDNEYS "\xef\x97\xbb"
#define ICON_FA_KISS "\xef\x96\x96"
#define ICON_FA_KISS_BEAM "\xef\x96\x97"
#define ICON_FA_KISS_WINK_HEART "\xef\x96\x98"
#define ICON_FA_KITE "\xef\x9b\xb4"
#define ICON_FA_KIWI_BIRD "\xef\x94\xb5"
#define ICON_FA_KNIFE_KITCHEN "\xef\x9b\xb5"
#define ICON_FA_LAMBDA "\xef\x99\xae"
#define ICON_FA_LAMP "\xef\x93\x8a"
#define ICON_FA_LAMP_DESK "\xee\x80\x94"
#define ICON_FA_LAMP_FLOOR "\xee\x80\x95"
#define ICON_FA_LANDMARK "\xef\x99\xaf"
#define ICON_FA_LANDMARK_ALT "\xef\x9d\x92"
#define ICON_FA_LANGUAGE "\xef\x86\xab"
#define ICON_FA_LAPTOP "\xef\x84\x89"
#define ICON_FA_LAPTOP_CODE "\xef\x97\xbc"
#define ICON_FA_LAPTOP_HOUSE "\xee\x81\xa6"
#define ICON_FA_LAPTOP_MEDICAL "\xef\xa0\x92"
#define ICON_FA_LASSO "\xef\xa3\x88"
#define ICON_FA_LAUGH "\xef\x96\x99"
#define ICON_FA_LAUGH_BEAM "\xef\x96\x9a"
#define ICON_FA_LAUGH_SQUINT "\xef\x96\x9b"
#define ICON_FA_LAUGH_WINK "\xef\x96\x9c"
#define ICON_FA_LAYER_GROUP "\xef\x97\xbd"
#define ICON_FA_LAYER_MINUS "\xef\x97\xbe"
#define ICON_FA_LAYER_PLUS "\xef\x97\xbf"
#define ICON_FA_LEAF "\xef\x81\xac"
#define ICON_FA_LEAF_HEART "\xef\x93\x8b"
#define ICON_FA_LEAF_MAPLE "\xef\x9b\xb6"
#define ICON_FA_LEAF_OAK "\xef\x9b\xb7"
#define ICON_FA_LEMON "\xef\x82\x94"
#define ICON_FA_LESS_THAN "\xef\x94\xb6"
#define ICON_FA_LESS_THAN_EQUAL "\xef\x94\xb7"
#define ICON_FA_LEVEL_DOWN "\xef\x85\x89"
#define ICON_FA_LEVEL_DOWN_ALT "\xef\x8e\xbe"
#define ICON_FA_LEVEL_UP "\xef\x85\x88"
#define ICON_FA_LEVEL_UP_ALT "\xef\x8e\xbf"
#define ICON_FA_LIFE_RING "\xef\x87\x8d"
#define ICON_FA_LIGHT_CEILING "\xee\x80\x96"
#define ICON_FA_LIGHT_SWITCH "\xee\x80\x97"
#define ICON_FA_LIGHT_SWITCH_OFF "\xee\x80\x98"
#define ICON_FA_LIGHT_SWITCH_ON "\xee\x80\x99"
#define ICON_FA_LIGHTBULB "\xef\x83\xab"
#define ICON_FA_LIGHTBULB_DOLLAR "\xef\x99\xb0"
#define ICON_FA_LIGHTBULB_EXCLAMATION "\xef\x99\xb1"
#define ICON_FA_LIGHTBULB_ON "\xef\x99\xb2"
#define ICON_FA_LIGHTBULB_SLASH "\xef\x99\xb3"
#define ICON_FA_LIGHTS_HOLIDAY "\xef\x9e\xb2"
#define ICON_FA_LINE_COLUMNS "\xef\xa1\xb0"
#define ICON_FA_LINE_HEIGHT "\xef\xa1\xb1"
#define ICON_FA_LINK "\xef\x83\x81"
#define ICON_FA_LIPS "\xef\x98\x80"
#define ICON_FA_LIRA_SIGN "\xef\x86\x95"
#define ICON_FA_LIST "\xef\x80\xba"
#define ICON_FA_LIST_ALT "\xef\x80\xa2"
#define ICON_FA_LIST_MUSIC "\xef\xa3\x89"
#define ICON_FA_LIST_OL "\xef\x83\x8b"
#define ICON_FA_LIST_UL "\xef\x83\x8a"
#define ICON_FA_LOCATION "\xef\x98\x81"
#define ICON_FA_LOCATION_ARROW "\xef\x84\xa4"
#define ICON_FA_LOCATION_CIRCLE "\xef\x98\x82"
#define ICON_FA_LOCATION_SLASH "\xef\x98\x83"
#define ICON_FA_LOCK "\xef\x80\xa3"
#define ICON_FA_LOCK_ALT "\xef\x8c\x8d"
#define ICON_FA_LOCK_OPEN "\xef\x8f\x81"
#define ICON_FA_LOCK_OPEN_ALT "\xef\x8f\x82"
#define ICON_FA_LONG_ARROW_ALT_DOWN "\xef\x8c\x89"
#define ICON_FA_LONG_ARROW_ALT_LEFT "\xef\x8c\x8a"
#define ICON_FA_LONG_ARROW_ALT_RIGHT "\xef\x8c\x8b"
#define ICON_FA_LONG_ARROW_ALT_UP "\xef\x8c\x8c"
#define ICON_FA_LONG_ARROW_DOWN "\xef\x85\xb5"
#define ICON_FA_LONG_ARROW_LEFT "\xef\x85\xb7"
#define ICON_FA_LONG_ARROW_RIGHT "\xef\x85\xb8"
#define ICON_FA_LONG_ARROW_UP "\xef\x85\xb6"
#define ICON_FA_LOVESEAT "\xef\x93\x8c"
#define ICON_FA_LOW_VISION "\xef\x8a\xa8"
#define ICON_FA_LUCHADOR "\xef\x91\x95"
#define ICON_FA_LUGGAGE_CART "\xef\x96\x9d"
#define ICON_FA_LUNGS "\xef\x98\x84"
#define ICON_FA_LUNGS_VIRUS "\xee\x81\xa7"
#define ICON_FA_MACE "\xef\x9b\xb8"
#define ICON_FA_MAGIC "\xef\x83\x90"
#define ICON_FA_MAGNET "\xef\x81\xb6"
#define ICON_FA_MAIL_BULK "\xef\x99\xb4"
#define ICON_FA_MAILBOX "\xef\xa0\x93"
#define ICON_FA_MALE "\xef\x86\x83"
#define ICON_FA_MANDOLIN "\xef\x9b\xb9"
#define ICON_FA_MAP "\xef\x89\xb9"
#define ICON_FA_MAP_MARKED "\xef\x96\x9f"
#define ICON_FA_MAP_MARKED_ALT "\xef\x96\xa0"
#define ICON_FA_MAP_MARKER "\xef\x81\x81"
#define ICON_FA_MAP_MARKER_ALT "\xef\x8f\x85"
#define ICON_FA_MAP_MARKER_ALT_SLASH "\xef\x98\x85"
#define ICON_FA_MAP_MARKER_CHECK "\xef\x98\x86"
#define ICON_FA_MAP_MARKER_EDIT "\xef\x98\x87"
#define ICON_FA_MAP_MARKER_EXCLAMATION "\xef\x98\x88"
#define ICON_FA_MAP_MARKER_MINUS "\xef\x98\x89"
#define ICON_FA_MAP_MARKER_PLUS "\xef\x98\x8a"
#define ICON_FA_MAP_MARKER_QUESTION "\xef\x98\x8b"
#define ICON_FA_MAP_MARKER_SLASH "\xef\x98\x8c"
#define ICON_FA_MAP_MARKER_SMILE "\xef\x98\x8d"
#define ICON_FA_MAP_MARKER_TIMES "\xef\x98\x8e"
#define ICON_FA_MAP_PIN "\xef\x89\xb6"
#define ICON_FA_MAP_SIGNS "\xef\x89\xb7"
#define ICON_FA_MARKER "\xef\x96\xa1"
#define ICON_FA_MARS "\xef\x88\xa2"
#define ICON_FA_MARS_DOUBLE "\xef\x88\xa7"
#define ICON_FA_MARS_STROKE "\xef\x88\xa9"
#define ICON_FA_MARS_STROKE_H "\xef\x88\xab"
#define ICON_FA_MARS_STROKE_V "\xef\x88\xaa"
#define ICON_FA_MASK "\xef\x9b\xba"
#define ICON_FA_MEAT "\xef\xa0\x94"
#define ICON_FA_MEDAL "\xef\x96\xa2"
#define ICON_FA_MEDKIT "\xef\x83\xba"
#define ICON_FA_MEGAPHONE "\xef\x99\xb5"
#define ICON_FA_MEH "\xef\x84\x9a"
#define ICON_FA_MEH_BLANK "\xef\x96\xa4"
#define ICON_FA_MEH_ROLLING_EYES "\xef\x96\xa5"
#define ICON_FA_MEMORY "\xef\x94\xb8"
#define ICON_FA_MENORAH "\xef\x99\xb6"
#define ICON_FA_MERCURY "\xef\x88\xa3"
#define ICON_FA_METEOR "\xef\x9d\x93"
#define ICON_FA_MICROCHIP "\xef\x8b\x9b"
#define ICON_FA_MICROPHONE "\xef\x84\xb0"
#define ICON_FA_MICROPHONE_ALT "\xef\x8f\x89"
#define ICON_FA_MICROPHONE_ALT_SLASH "\xef\x94\xb9"
#define ICON_FA_MICROPHONE_SLASH "\xef\x84\xb1"
#define ICON_FA_MICROPHONE_STAND "\xef\xa3\x8b"
#define ICON_FA_MICROSCOPE "\xef\x98\x90"
#define ICON_FA_MICROWAVE "\xee\x80\x9b"
#define ICON_FA_MIND_SHARE "\xef\x99\xb7"
#define ICON_FA_MINUS "\xef\x81\xa8"
#define ICON_FA_MINUS_CIRCLE "\xef\x81\x96"
#define ICON_FA_MINUS_HEXAGON "\xef\x8c\x87"
#define ICON_FA_MINUS_OCTAGON "\xef\x8c\x88"
#define ICON_FA_MINUS_SQUARE "\xef\x85\x86"
#define ICON_FA_MISTLETOE "\xef\x9e\xb4"
#define ICON_FA_MITTEN "\xef\x9e\xb5"
#define ICON_FA_MOBILE "\xef\x84\x8b"
#define ICON_FA_MOBILE_ALT "\xef\x8f\x8d"
#define ICON_FA_MOBILE_ANDROID "\xef\x8f\x8e"
#define ICON_FA_MOBILE_ANDROID_ALT "\xef\x8f\x8f"
#define ICON_FA_MONEY_BILL "\xef\x83\x96"
#define ICON_FA_MONEY_BILL_ALT "\xef\x8f\x91"
#define ICON_FA_MONEY_BILL_WAVE "\xef\x94\xba"
#define ICON_FA_MONEY_BILL_WAVE_ALT "\xef\x94\xbb"
#define ICON_FA_MONEY_CHECK "\xef\x94\xbc"
#define ICON_FA_MONEY_CHECK_ALT "\xef\x94\xbd"
#define ICON_FA_MONEY_CHECK_EDIT "\xef\xa1\xb2"
#define ICON_FA_MONEY_CHECK_EDIT_ALT "\xef\xa1\xb3"
#define ICON_FA_MONITOR_HEART_RATE "\xef\x98\x91"
#define ICON_FA_MONKEY "\xef\x9b\xbb"
#define ICON_FA_MONUMENT "\xef\x96\xa6"
#define ICON_FA_MOON "\xef\x86\x86"
#define ICON_FA_MOON_CLOUD "\xef\x9d\x94"
#define ICON_FA_MOON_STARS "\xef\x9d\x95"
#define ICON_FA_MORTAR_PESTLE "\xef\x96\xa7"
#define ICON_FA_MOSQUE "\xef\x99\xb8"
#define ICON_FA_MOTORCYCLE "\xef\x88\x9c"
#define ICON_FA_MOUNTAIN "\xef\x9b\xbc"
#define ICON_FA_MOUNTAINS "\xef\x9b\xbd"
#define ICON_FA_MOUSE "\xef\xa3\x8c"
#define ICON_FA_MOUSE_ALT "\xef\xa3\x8d"
#define ICON_FA_MOUSE_POINTER "\xef\x89\x85"
#define ICON_FA_MP3_PLAYER "\xef\xa3\x8e"
#define ICON_FA_MUG "\xef\xa1\xb4"
#define ICON_FA_MUG_HOT "\xef\x9e\xb6"
#define ICON_FA_MUG_MARSHMALLOWS "\xef\x9e\xb7"
#define ICON_FA_MUG_TEA "\xef\xa1\xb5"
#define ICON_FA_MUSIC "\xef\x80\x81"
#define ICON_FA_MUSIC_ALT "\xef\xa3\x8f"
#define ICON_FA_MUSIC_ALT_SLASH "\xef\xa3\x90"
#define ICON_FA_MUSIC_SLASH "\xef\xa3\x91"
#define ICON_FA_NARWHAL "\xef\x9b\xbe"
#define ICON_FA_NETWORK_WIRED "\xef\x9b\xbf"
#define ICON_FA_NEUTER "\xef\x88\xac"
#define ICON_FA_NEWSPAPER "\xef\x87\xaa"
#define ICON_FA_NOT_EQUAL "\xef\x94\xbe"
#define ICON_FA_NOTES_MEDICAL "\xef\x92\x81"
#define ICON_FA_OBJECT_GROUP "\xef\x89\x87"
#define ICON_FA_OBJECT_UNGROUP "\xef\x89\x88"
#define ICON_FA_OCTAGON "\xef\x8c\x86"
#define ICON_FA_OIL_CAN "\xef\x98\x93"
#define ICON_FA_OIL_TEMP "\xef\x98\x94"
#define ICON_FA_OM "\xef\x99\xb9"
#define ICON_FA_OMEGA "\xef\x99\xba"
#define ICON_FA_ORNAMENT "\xef\x9e\xb8"
#define ICON_FA_OTTER "\xef\x9c\x80"
#define ICON_FA_OUTDENT "\xef\x80\xbb"
#define ICON_FA_OUTLET "\xee\x80\x9c"
#define ICON_FA_OVEN "\xee\x80\x9d"
#define ICON_FA_OVERLINE "\xef\xa1\xb6"
#define ICON_FA_PAGE_BREAK "\xef\xa1\xb7"
#define ICON_FA_PAGER "\xef\xa0\x95"
#define ICON_FA_PAINT_BRUSH "\xef\x87\xbc"
#define ICON_FA_PAINT_BRUSH_ALT "\xef\x96\xa9"
#define ICON_FA_PAINT_ROLLER "\xef\x96\xaa"
#define ICON_FA_PALETTE "\xef\x94\xbf"
#define ICON_FA_PALLET "\xef\x92\x82"
#define ICON_FA_PALLET_ALT "\xef\x92\x83"
#define ICON_FA_PAPER_PLANE "\xef\x87\x98"
#define ICON_FA_PAPERCLIP "\xef\x83\x86"
#define ICON_FA_PARACHUTE_BOX "\xef\x93\x8d"
#define ICON_FA_PARAGRAPH "\xef\x87\x9d"
#define ICON_FA_PARAGRAPH_RTL "\xef\xa1\xb8"
#define ICON_FA_PARKING "\xef\x95\x80"
#define ICON_FA_PARKING_CIRCLE "\xef\x98\x95"
#define ICON_FA_PARKING_CIRCLE_SLASH "\xef\x98\x96"
#define ICON_FA_PARKING_SLASH "\xef\x98\x97"
#define ICON_FA_PASSPORT "\xef\x96\xab"
#define ICON_FA_PASTAFARIANISM "\xef\x99\xbb"
#define ICON_FA_PASTE "\xef\x83\xaa"
#define ICON_FA_PAUSE "\xef\x81\x8c"
#define ICON_FA_PAUSE_CIRCLE "\xef\x8a\x8b"
#define ICON_FA_PAW "\xef\x86\xb0"
#define ICON_FA_PAW_ALT "\xef\x9c\x81"
#define ICON_FA_PAW_CLAWS "\xef\x9c\x82"
#define ICON_FA_PEACE "\xef\x99\xbc"
#define ICON_FA_PEGASUS "\xef\x9c\x83"
#define ICON_FA_PEN "\xef\x8c\x84"
#define ICON_FA_PEN_ALT "\xef\x8c\x85"
#define ICON_FA_PEN_FANCY "\xef\x96\xac"
#define ICON_FA_PEN_NIB "\xef\x96\xad"
#define ICON_FA_PEN_SQUARE "\xef\x85\x8b"
#define ICON_FA_PENCIL "\xef\x81\x80"
#define ICON_FA_PENCIL_ALT "\xef\x8c\x83"
#define ICON_FA_PENCIL_PAINTBRUSH "\xef\x98\x98"
#define ICON_FA_PENCIL_RULER "\xef\x96\xae"
#define ICON_FA_PENNANT "\xef\x91\x96"
#define ICON_FA_PEOPLE_ARROWS "\xee\x81\xa8"
#define ICON_FA_PEOPLE_CARRY "\xef\x93\x8e"
#define ICON_FA_PEPPER_HOT "\xef\xa0\x96"
#define ICON_FA_PERCENT "\xef\x8a\x95"
#define ICON_FA_PERCENTAGE "\xef\x95\x81"
#define ICON_FA_PERSON_BOOTH "\xef\x9d\x96"
#define ICON_FA_PERSON_CARRY "\xef\x93\x8f"
#define ICON_FA_PERSON_DOLLY "\xef\x93\x90"
#define ICON_FA_PERSON_DOLLY_EMPTY "\xef\x93\x91"
#define ICON_FA_PERSON_SIGN "\xef\x9d\x97"
#define ICON_FA_PHONE "\xef\x82\x95"
#define ICON_FA_PHONE_ALT "\xef\xa1\xb9"
#define ICON_FA_PHONE_LAPTOP "\xef\xa1\xba"
#define ICON_FA_PHONE_OFFICE "\xef\x99\xbd"
#define ICON_FA_PHONE_PLUS "\xef\x93\x92"
#define ICON_FA_PHONE_ROTARY "\xef\xa3\x93"
#define ICON_FA_PHONE_SLASH "\xef\x8f\x9d"
#define ICON_FA_PHONE_SQUARE "\xef\x82\x98"
#define ICON_FA_PHONE_SQUARE_ALT "\xef\xa1\xbb"
#define ICON_FA_PHONE_VOLUME "\xef\x8a\xa0"
#define ICON_FA_PHOTO_VIDEO "\xef\xa1\xbc"
#define ICON_FA_PI "\xef\x99\xbe"
#define ICON_FA_PIANO "\xef\xa3\x94"
#define ICON_FA_PIANO_KEYBOARD "\xef\xa3\x95"
#define ICON_FA_PIE "\xef\x9c\x85"
#define ICON_FA_PIG "\xef\x9c\x86"
#define ICON_FA_PIGGY_BANK "\xef\x93\x93"
#define ICON_FA_PILLS "\xef\x92\x84"
#define ICON_FA_PIZZA "\xef\xa0\x97"
#define ICON_FA_PIZZA_SLICE "\xef\xa0\x98"
#define ICON_FA_PLACE_OF_WORSHIP "\xef\x99\xbf"
#define ICON_FA_PLANE "\xef\x81\xb2"
#define ICON_FA_PLANE_ALT "\xef\x8f\x9e"
#define ICON_FA_PLANE_ARRIVAL "\xef\x96\xaf"
#define ICON_FA_PLANE_DEPARTURE "\xef\x96\xb0"
#define ICON_FA_PLANE_SLASH "\xee\x81\xa9"
#define ICON_FA_PLANET_MOON "\xee\x80\x9f"
#define ICON_FA_PLANET_RINGED "\xee\x80\xa0"
#define ICON_FA_PLAY "\xef\x81\x8b"
#define ICON_FA_PLAY_CIRCLE "\xef\x85\x84"
#define ICON_FA_PLUG "\xef\x87\xa6"
#define ICON_FA_PLUS "\xef\x81\xa7"
#define ICON_FA_PLUS_CIRCLE "\xef\x81\x95"
#define ICON_FA_PLUS_HEXAGON "\xef\x8c\x80"
#define ICON_FA_PLUS_OCTAGON "\xef\x8c\x81"
#define ICON_FA_PLUS_SQUARE "\xef\x83\xbe"
#define ICON_FA_PODCAST "\xef\x8b\x8e"
#define ICON_FA_PODIUM "\xef\x9a\x80"
#define ICON_FA_PODIUM_STAR "\xef\x9d\x98"
#define ICON_FA_POLICE_BOX "\xee\x80\xa1"
#define ICON_FA_POLL "\xef\x9a\x81"
#define ICON_FA_POLL_H "\xef\x9a\x82"
#define ICON_FA_POLL_PEOPLE "\xef\x9d\x99"
#define ICON_FA_POO "\xef\x8b\xbe"
#define ICON_FA_POO_STORM "\xef\x9d\x9a"
#define ICON_FA_POOP "\xef\x98\x99"
#define ICON_FA_POPCORN "\xef\xa0\x99"
#define ICON_FA_PORTAL_ENTER "\xee\x80\xa2"
#define ICON_FA_PORTAL_EXIT "\xee\x80\xa3"
#define ICON_FA_PORTRAIT "\xef\x8f\xa0"
#define ICON_FA_POUND_SIGN "\xef\x85\x94"
#define ICON_FA_POWER_OFF "\xef\x80\x91"
#define ICON_FA_PRAY "\xef\x9a\x83"
#define ICON_FA_PRAYING_HANDS "\xef\x9a\x84"
#define ICON_FA_PRESCRIPTION "\xef\x96\xb1"
#define ICON_FA_PRESCRIPTION_BOTTLE "\xef\x92\x85"
#define ICON_FA_PRESCRIPTION_BOTTLE_ALT "\xef\x92\x86"
#define ICON_FA_PRESENTATION "\xef\x9a\x85"
#define ICON_FA_PRINT "\xef\x80\xaf"
#define ICON_FA_PRINT_SEARCH "\xef\xa0\x9a"
#define ICON_FA_PRINT_SLASH "\xef\x9a\x86"
#define ICON_FA_PROCEDURES "\xef\x92\x87"
#define ICON_FA_PROJECT_DIAGRAM "\xef\x95\x82"
#define ICON_FA_PROJECTOR "\xef\xa3\x96"
#define ICON_FA_PUMP_MEDICAL "\xee\x81\xaa"
#define ICON_FA_PUMP_SOAP "\xee\x81\xab"
#define ICON_FA_PUMPKIN "\xef\x9c\x87"
#define ICON_FA_PUZZLE_PIECE "\xef\x84\xae"
#define ICON_FA_QRCODE "\xef\x80\xa9"
#define ICON_FA_QUESTION "\xef\x84\xa8"
#define ICON_FA_QUESTION_CIRCLE "\xef\x81\x99"
#define ICON_FA_QUESTION_SQUARE "\xef\x8b\xbd"
#define ICON_FA_QUIDDITCH "\xef\x91\x98"
#define ICON_FA_QUOTE_LEFT "\xef\x84\x8d"
#define ICON_FA_QUOTE_RIGHT "\xef\x84\x8e"
#define ICON_FA_QURAN "\xef\x9a\x87"
#define ICON_FA_RABBIT "\xef\x9c\x88"
#define ICON_FA_RABBIT_FAST "\xef\x9c\x89"
#define ICON_FA_RACQUET "\xef\x91\x9a"
#define ICON_FA_RADAR "\xee\x80\xa4"
#define ICON_FA_RADIATION "\xef\x9e\xb9"
#define ICON_FA_RADIATION_ALT "\xef\x9e\xba"
#define ICON_FA_RADIO "\xef\xa3\x97"
#define ICON_FA_RADIO_ALT "\xef\xa3\x98"
#define ICON_FA_RAINBOW "\xef\x9d\x9b"
#define ICON_FA_RAINDROPS "\xef\x9d\x9c"
#define ICON_FA_RAM "\xef\x9c\x8a"
#define ICON_FA_RAMP_LOADING "\xef\x93\x94"
#define ICON_FA_RANDOM "\xef\x81\xb4"
#define ICON_FA_RAYGUN "\xee\x80\xa5"
#define ICON_FA_RECEIPT "\xef\x95\x83"
#define ICON_FA_RECORD_VINYL "\xef\xa3\x99"
#define ICON_FA_RECTANGLE_LANDSCAPE "\xef\x8b\xba"
#define ICON_FA_RECTANGLE_PORTRAIT "\xef\x8b\xbb"
#define ICON_FA_RECTANGLE_WIDE "\xef\x8b\xbc"
#define ICON_FA_RECYCLE "\xef\x86\xb8"
#define ICON_FA_REDO "\xef\x80\x9e"
#define ICON_FA_REDO_ALT "\xef\x8b\xb9"
#define ICON_FA_REFRIGERATOR "\xee\x80\xa6"
#define ICON_FA_REGISTERED "\xef\x89\x9d"
#define ICON_FA_REMOVE_FORMAT "\xef\xa1\xbd"
#define ICON_FA_REPEAT "\xef\x8d\xa3"
#define ICON_FA_REPEAT_1 "\xef\x8d\xa5"
#define ICON_FA_REPEAT_1_ALT "\xef\x8d\xa6"
#define ICON_FA_REPEAT_ALT "\xef\x8d\xa4"
#define ICON_FA_REPLY "\xef\x8f\xa5"
#define ICON_FA_REPLY_ALL "\xef\x84\xa2"
#define ICON_FA_REPUBLICAN "\xef\x9d\x9e"
#define ICON_FA_RESTROOM "\xef\x9e\xbd"
#define ICON_FA_RETWEET "\xef\x81\xb9"
#define ICON_FA_RETWEET_ALT "\xef\x8d\xa1"
#define ICON_FA_RIBBON "\xef\x93\x96"
#define ICON_FA_RING "\xef\x9c\x8b"
#define ICON_FA_RINGS_WEDDING "\xef\xa0\x9b"
#define ICON_FA_ROAD "\xef\x80\x98"
#define ICON_FA_ROBOT "\xef\x95\x84"
#define ICON_FA_ROCKET "\xef\x84\xb5"
#define ICON_FA_ROCKET_LAUNCH "\xee\x80\xa7"
#define ICON_FA_ROUTE "\xef\x93\x97"
#define ICON_FA_ROUTE_HIGHWAY "\xef\x98\x9a"
#define ICON_FA_ROUTE_INTERSTATE "\xef\x98\x9b"
#define ICON_FA_ROUTER "\xef\xa3\x9a"
#define ICON_FA_RSS "\xef\x82\x9e"
#define ICON_FA_RSS_SQUARE "\xef\x85\x83"
#define ICON_FA_RUBLE_SIGN "\xef\x85\x98"
#define ICON_FA_RULER "\xef\x95\x85"
#define ICON_FA_RULER_COMBINED "\xef\x95\x86"
#define ICON_FA_RULER_HORIZONTAL "\xef\x95\x87"
#define ICON_FA_RULER_TRIANGLE "\xef\x98\x9c"
#define ICON_FA_RULER_VERTICAL "\xef\x95\x88"
#define ICON_FA_RUNNING "\xef\x9c\x8c"
#define ICON_FA_RUPEE_SIGN "\xef\x85\x96"
#define ICON_FA_RV "\xef\x9e\xbe"
#define ICON_FA_SACK "\xef\xa0\x9c"
#define ICON_FA_SACK_DOLLAR "\xef\xa0\x9d"
#define ICON_FA_SAD_CRY "\xef\x96\xb3"
#define ICON_FA_SAD_TEAR "\xef\x96\xb4"
#define ICON_FA_SALAD "\xef\xa0\x9e"
#define ICON_FA_SANDWICH "\xef\xa0\x9f"
#define ICON_FA_SATELLITE "\xef\x9e\xbf"
#define ICON_FA_SATELLITE_DISH "\xef\x9f\x80"
#define ICON_FA_SAUSAGE "\xef\xa0\xa0"
#define ICON_FA_SAVE "\xef\x83\x87"
#define ICON_FA_SAX_HOT "\xef\xa3\x9b"
#define ICON_FA_SAXOPHONE "\xef\xa3\x9c"
#define ICON_FA_SCALPEL "\xef\x98\x9d"
#define ICON_FA_SCALPEL_PATH "\xef\x98\x9e"
#define ICON_FA_SCANNER "\xef\x92\x88"
#define ICON_FA_SCANNER_IMAGE "\xef\xa3\xb3"
#define ICON_FA_SCANNER_KEYBOARD "\xef\x92\x89"
#define ICON_FA_SCANNER_TOUCHSCREEN "\xef\x92\x8a"
#define ICON_FA_SCARECROW "\xef\x9c\x8d"
#define ICON_FA_SCARF "\xef\x9f\x81"
#define ICON_FA_SCHOOL "\xef\x95\x89"
#define ICON_FA_SCREWDRIVER "\xef\x95\x8a"
#define ICON_FA_SCROLL "\xef\x9c\x8e"
#define ICON_FA_SCROLL_OLD "\xef\x9c\x8f"
#define ICON_FA_SCRUBBER "\xef\x8b\xb8"
#define ICON_FA_SCYTHE "\xef\x9c\x90"
#define ICON_FA_SD_CARD "\xef\x9f\x82"
#define ICON_FA_SEARCH "\xef\x80\x82"
#define ICON_FA_SEARCH_DOLLAR "\xef\x9a\x88"
#define ICON_FA_SEARCH_LOCATION "\xef\x9a\x89"
#define ICON_FA_SEARCH_MINUS "\xef\x80\x90"
#define ICON_FA_SEARCH_PLUS "\xef\x80\x8e"
#define ICON_FA_SEEDLING "\xef\x93\x98"
#define ICON_FA_SEND_BACK "\xef\xa1\xbe"
#define ICON_FA_SEND_BACKWARD "\xef\xa1\xbf"
#define ICON_FA_SENSOR "\xee\x80\xa8"
#define ICON_FA_SENSOR_ALERT "\xee\x80\xa9"
#define ICON_FA_SENSOR_FIRE "\xee\x80\xaa"
#define ICON_FA_SENSOR_ON "\xee\x80\xab"
#define ICON_FA_SENSOR_SMOKE "\xee\x80\xac"
#define ICON_FA_SERVER "\xef\x88\xb3"
#define ICON_FA_SHAPES "\xef\x98\x9f"
#define ICON_FA_SHARE "\xef\x81\xa4"
#define ICON_FA_SHARE_ALL "\xef\x8d\xa7"
#define ICON_FA_SHARE_ALT "\xef\x87\xa0"
#define ICON_FA_SHARE_ALT_SQUARE "\xef\x87\xa1"
#define ICON_FA_SHARE_SQUARE "\xef\x85\x8d"
#define ICON_FA_SHEEP "\xef\x9c\x91"
#define ICON_FA_SHEKEL_SIGN "\xef\x88\x8b"
#define ICON_FA_SHIELD "\xef\x84\xb2"
#define ICON_FA_SHIELD_ALT "\xef\x8f\xad"
#define ICON_FA_SHIELD_CHECK "\xef\x8b\xb7"
#define ICON_FA_SHIELD_CROSS "\xef\x9c\x92"
#define ICON_FA_SHIELD_VIRUS "\xee\x81\xac"
#define ICON_FA_SHIP "\xef\x88\x9a"
#define ICON_FA_SHIPPING_FAST "\xef\x92\x8b"
#define ICON_FA_SHIPPING_TIMED "\xef\x92\x8c"
#define ICON_FA_SHISH_KEBAB "\xef\xa0\xa1"
#define ICON_FA_SHOE_PRINTS "\xef\x95\x8b"
#define ICON_FA_SHOPPING_BAG "\xef\x8a\x90"
#define ICON_FA_SHOPPING_BASKET "\xef\x8a\x91"
#define ICON_FA_SHOPPING_CART "\xef\x81\xba"
#define ICON_FA_SHOVEL "\xef\x9c\x93"
#define ICON_FA_SHOVEL_SNOW "\xef\x9f\x83"
#define ICON_FA_SHOWER "\xef\x8b\x8c"
#define ICON_FA_SHREDDER "\xef\x9a\x8a"
#define ICON_FA_SHUTTLE_VAN "\xef\x96\xb6"
#define ICON_FA_SHUTTLECOCK "\xef\x91\x9b"
#define ICON_FA_SICKLE "\xef\xa0\xa2"
#define ICON_FA_SIGMA "\xef\x9a\x8b"
#define ICON_FA_SIGN "\xef\x93\x99"
#define ICON_FA_SIGN_IN "\xef\x82\x90"
#define ICON_FA_SIGN_IN_ALT "\xef\x8b\xb6"
#define ICON_FA_SIGN_LANGUAGE "\xef\x8a\xa7"
#define ICON_FA_SIGN_OUT "\xef\x82\x8b"
#define ICON_FA_SIGN_OUT_ALT "\xef\x8b\xb5"
#define ICON_FA_SIGNAL "\xef\x80\x92"
#define ICON_FA_SIGNAL_1 "\xef\x9a\x8c"
#define ICON_FA_SIGNAL_2 "\xef\x9a\x8d"
#define ICON_FA_SIGNAL_3 "\xef\x9a\x8e"
#define ICON_FA_SIGNAL_4 "\xef\x9a\x8f"
#define ICON_FA_SIGNAL_ALT "\xef\x9a\x90"
#define ICON_FA_SIGNAL_ALT_1 "\xef\x9a\x91"
#define ICON_FA_SIGNAL_ALT_2 "\xef\x9a\x92"
#define ICON_FA_SIGNAL_ALT_3 "\xef\x9a\x93"
#define ICON_FA_SIGNAL_ALT_SLASH "\xef\x9a\x94"
#define ICON_FA_SIGNAL_SLASH "\xef\x9a\x95"
#define ICON_FA_SIGNAL_STREAM "\xef\xa3\x9d"
#define ICON_FA_SIGNATURE "\xef\x96\xb7"
#define ICON_FA_SIM_CARD "\xef\x9f\x84"
#define ICON_FA_SINK "\xee\x81\xad"
#define ICON_FA_SIREN "\xee\x80\xad"
#define ICON_FA_SIREN_ON "\xee\x80\xae"
#define ICON_FA_SITEMAP "\xef\x83\xa8"
#define ICON_FA_SKATING "\xef\x9f\x85"
#define ICON_FA_SKELETON "\xef\x98\xa0"
#define ICON_FA_SKI_JUMP "\xef\x9f\x87"
#define ICON_FA_SKI_LIFT "\xef\x9f\x88"
#define ICON_FA_SKIING "\xef\x9f\x89"
#define ICON_FA_SKIING_NORDIC "\xef\x9f\x8a"
#define ICON_FA_SKULL "\xef\x95\x8c"
#define ICON_FA_SKULL_COW "\xef\xa3\x9e"
#define ICON_FA_SKULL_CROSSBONES "\xef\x9c\x94"
#define ICON_FA_SLASH "\xef\x9c\x95"
#define ICON_FA_SLEDDING "\xef\x9f\x8b"
#define ICON_FA_SLEIGH "\xef\x9f\x8c"
#define ICON_FA_SLIDERS_H "\xef\x87\x9e"
#define ICON_FA_SLIDERS_H_SQUARE "\xef\x8f\xb0"
#define ICON_FA_SLIDERS_V "\xef\x8f\xb1"
#define ICON_FA_SLIDERS_V_SQUARE "\xef\x8f\xb2"
#define ICON_FA_SMILE "\xef\x84\x98"
#define ICON_FA_SMILE_BEAM "\xef\x96\xb8"
#define ICON_FA_SMILE_PLUS "\xef\x96\xb9"
#define ICON_FA_SMILE_WINK "\xef\x93\x9a"
#define ICON_FA_SMOG "\xef\x9d\x9f"
#define ICON_FA_SMOKE "\xef\x9d\xa0"
#define ICON_FA_SMOKING "\xef\x92\x8d"
#define ICON_FA_SMOKING_BAN "\xef\x95\x8d"
#define ICON_FA_SMS "\xef\x9f\x8d"
#define ICON_FA_SNAKE "\xef\x9c\x96"
#define ICON_FA_SNOOZE "\xef\xa2\x80"
#define ICON_FA_SNOW_BLOWING "\xef\x9d\xa1"
#define ICON_FA_SNOWBOARDING "\xef\x9f\x8e"
#define ICON_FA_SNOWFLAKE "\xef\x8b\x9c"
#define ICON_FA_SNOWFLAKES "\xef\x9f\x8f"
#define ICON_FA_SNOWMAN "\xef\x9f\x90"
#define ICON_FA_SNOWMOBILE "\xef\x9f\x91"
#define ICON_FA_SNOWPLOW "\xef\x9f\x92"
#define ICON_FA_SOAP "\xee\x81\xae"
#define ICON_FA_SOCKS "\xef\x9a\x96"
#define ICON_FA_SOLAR_PANEL "\xef\x96\xba"
#define ICON_FA_SOLAR_SYSTEM "\xee\x80\xaf"
#define ICON_FA_SORT "\xef\x83\x9c"
#define ICON_FA_SORT_ALPHA_DOWN "\xef\x85\x9d"
#define ICON_FA_SORT_ALPHA_DOWN_ALT "\xef\xa2\x81"
#define ICON_FA_SORT_ALPHA_UP "\xef\x85\x9e"
#define ICON_FA_SORT_ALPHA_UP_ALT "\xef\xa2\x82"
#define ICON_FA_SORT_ALT "\xef\xa2\x83"
#define ICON_FA_SORT_AMOUNT_DOWN "\xef\x85\xa0"
#define ICON_FA_SORT_AMOUNT_DOWN_ALT "\xef\xa2\x84"
#define ICON_FA_SORT_AMOUNT_UP "\xef\x85\xa1"
#define ICON_FA_SORT_AMOUNT_UP_ALT "\xef\xa2\x85"
#define ICON_FA_SORT_CIRCLE "\xee\x80\xb0"
#define ICON_FA_SORT_CIRCLE_DOWN "\xee\x80\xb1"
#define ICON_FA_SORT_CIRCLE_UP "\xee\x80\xb2"
#define ICON_FA_SORT_DOWN "\xef\x83\x9d"
#define ICON_FA_SORT_NUMERIC_DOWN "\xef\x85\xa2"
#define ICON_FA_SORT_NUMERIC_DOWN_ALT "\xef\xa2\x86"
#define ICON_FA_SORT_NUMERIC_UP "\xef\x85\xa3"
#define ICON_FA_SORT_NUMERIC_UP_ALT "\xef\xa2\x87"
#define ICON_FA_SORT_SHAPES_DOWN "\xef\xa2\x88"
#define ICON_FA_SORT_SHAPES_DOWN_ALT "\xef\xa2\x89"
#define ICON_FA_SORT_SHAPES_UP "\xef\xa2\x8a"
#define ICON_FA_SORT_SHAPES_UP_ALT "\xef\xa2\x8b"
#define ICON_FA_SORT_SIZE_DOWN "\xef\xa2\x8c"
#define ICON_FA_SORT_SIZE_DOWN_ALT "\xef\xa2\x8d"
#define ICON_FA_SORT_SIZE_UP "\xef\xa2\x8e"
#define ICON_FA_SORT_SIZE_UP_ALT "\xef\xa2\x8f"
#define ICON_FA_SORT_UP "\xef\x83\x9e"
#define ICON_FA_SOUP "\xef\xa0\xa3"
#define ICON_FA_SPA "\xef\x96\xbb"
#define ICON_FA_SPACE_SHUTTLE "\xef\x86\x97"
#define ICON_FA_SPACE_STATION_MOON "\xee\x80\xb3"
#define ICON_FA_SPACE_STATION_MOON_ALT "\xee\x80\xb4"
#define ICON_FA_SPADE "\xef\x8b\xb4"
#define ICON_FA_SPARKLES "\xef\xa2\x90"
#define ICON_FA_SPEAKER "\xef\xa3\x9f"
#define ICON_FA_SPEAKERS "\xef\xa3\xa0"
#define ICON_FA_SPELL_CHECK "\xef\xa2\x91"
#define ICON_FA_SPIDER "\xef\x9c\x97"
#define ICON_FA_SPIDER_BLACK_WIDOW "\xef\x9c\x98"
#define ICON_FA_SPIDER_WEB "\xef\x9c\x99"
#define ICON_FA_SPINNER "\xef\x84\x90"
#define ICON_FA_SPINNER_THIRD "\xef\x8f\xb4"
#define ICON_FA_SPLOTCH "\xef\x96\xbc"
#define ICON_FA_SPRAY_CAN "\xef\x96\xbd"
#define ICON_FA_SPRINKLER "\xee\x80\xb5"
#define ICON_FA_SQUARE "\xef\x83\x88"
#define ICON_FA_SQUARE_FULL "\xef\x91\x9c"
#define ICON_FA_SQUARE_ROOT "\xef\x9a\x97"
#define ICON_FA_SQUARE_ROOT_ALT "\xef\x9a\x98"
#define ICON_FA_SQUIRREL "\xef\x9c\x9a"
#define ICON_FA_STAFF "\xef\x9c\x9b"
#define ICON_FA_STAMP "\xef\x96\xbf"
#define ICON_FA_STAR "\xef\x80\x85"
#define ICON_FA_STAR_AND_CRESCENT "\xef\x9a\x99"
#define ICON_FA_STAR_CHRISTMAS "\xef\x9f\x94"
#define ICON_FA_STAR_EXCLAMATION "\xef\x8b\xb3"
#define ICON_FA_STAR_HALF "\xef\x82\x89"
#define ICON_FA_STAR_HALF_ALT "\xef\x97\x80"
#define ICON_FA_STAR_OF_DAVID "\xef\x9a\x9a"
#define ICON_FA_STAR_OF_LIFE "\xef\x98\xa1"
#define ICON_FA_STAR_SHOOTING "\xee\x80\xb6"
#define ICON_FA_STARFIGHTER "\xee\x80\xb7"
#define ICON_FA_STARFIGHTER_ALT "\xee\x80\xb8"
#define ICON_FA_STARS "\xef\x9d\xa2"
#define ICON_FA_STARSHIP "\xee\x80\xb9"
#define ICON_FA_STARSHIP_FREIGHTER "\xee\x80\xba"
#define ICON_FA_STEAK "\xef\xa0\xa4"
#define ICON_FA_STEERING_WHEEL "\xef\x98\xa2"
#define ICON_FA_STEP_BACKWARD "\xef\x81\x88"
#define ICON_FA_STEP_FORWARD "\xef\x81\x91"
#define ICON_FA_STETHOSCOPE "\xef\x83\xb1"
#define ICON_FA_STICKY_NOTE "\xef\x89\x89"
#define ICON_FA_STOCKING "\xef\x9f\x95"
#define ICON_FA_STOMACH "\xef\x98\xa3"
#define ICON_FA_STOP "\xef\x81\x8d"
#define ICON_FA_STOP_CIRCLE "\xef\x8a\x8d"
#define ICON_FA_STOPWATCH "\xef\x8b\xb2"
#define ICON_FA_STOPWATCH_20 "\xee\x81\xaf"
#define ICON_FA_STORE "\xef\x95\x8e"
#define ICON_FA_STORE_ALT "\xef\x95\x8f"
#define ICON_FA_STORE_ALT_SLASH "\xee\x81\xb0"
#define ICON_FA_STORE_SLASH "\xee\x81\xb1"
#define ICON_FA_STREAM "\xef\x95\x90"
#define ICON_FA_STREET_VIEW "\xef\x88\x9d"
#define ICON_FA_STRETCHER "\xef\xa0\xa5"
#define ICON_FA_STRIKETHROUGH "\xef\x83\x8c"
#define ICON_FA_STROOPWAFEL "\xef\x95\x91"
#define ICON_FA_SUBSCRIPT "\xef\x84\xac"
#define ICON_FA_SUBWAY "\xef\x88\xb9"
#define ICON_FA_SUITCASE "\xef\x83\xb2"
#define ICON_FA_SUITCASE_ROLLING "\xef\x97\x81"
#define ICON_FA_SUN "\xef\x86\x85"
#define ICON_FA_SUN_CLOUD "\xef\x9d\xa3"
#define ICON_FA_SUN_DUST "\xef\x9d\xa4"
#define ICON_FA_SUN_HAZE "\xef\x9d\xa5"
#define ICON_FA_SUNGLASSES "\xef\xa2\x92"
#define ICON_FA_SUNRISE "\xef\x9d\xa6"
#define ICON_FA_SUNSET "\xef\x9d\xa7"
#define ICON_FA_SUPERSCRIPT "\xef\x84\xab"
#define ICON_FA_SURPRISE "\xef\x97\x82"
#define ICON_FA_SWATCHBOOK "\xef\x97\x83"
#define ICON_FA_SWIMMER "\xef\x97\x84"
#define ICON_FA_SWIMMING_POOL "\xef\x97\x85"
#define ICON_FA_SWORD "\xef\x9c\x9c"
#define ICON_FA_SWORD_LASER "\xee\x80\xbb"
#define ICON_FA_SWORD_LASER_ALT "\xee\x80\xbc"
#define ICON_FA_SWORDS "\xef\x9c\x9d"
#define ICON_FA_SWORDS_LASER "\xee\x80\xbd"
#define ICON_FA_SYNAGOGUE "\xef\x9a\x9b"
#define ICON_FA_SYNC "\xef\x80\xa1"
#define ICON_FA_SYNC_ALT "\xef\x8b\xb1"
#define ICON_FA_SYRINGE "\xef\x92\x8e"
#define ICON_FA_TABLE "\xef\x83\x8e"
#define ICON_FA_TABLE_TENNIS "\xef\x91\x9d"
#define ICON_FA_TABLET "\xef\x84\x8a"
#define ICON_FA_TABLET_ALT "\xef\x8f\xba"
#define ICON_FA_TABLET_ANDROID "\xef\x8f\xbb"
#define ICON_FA_TABLET_ANDROID_ALT "\xef\x8f\xbc"
#define ICON_FA_TABLET_RUGGED "\xef\x92\x8f"
#define ICON_FA_TABLETS "\xef\x92\x90"
#define ICON_FA_TACHOMETER "\xef\x83\xa4"
#define ICON_FA_TACHOMETER_ALT "\xef\x8f\xbd"
#define ICON_FA_TACHOMETER_ALT_AVERAGE "\xef\x98\xa4"
#define ICON_FA_TACHOMETER_ALT_FAST "\xef\x98\xa5"
#define ICON_FA_TACHOMETER_ALT_FASTEST "\xef\x98\xa6"
#define ICON_FA_TACHOMETER_ALT_SLOW "\xef\x98\xa7"
#define ICON_FA_TACHOMETER_ALT_SLOWEST "\xef\x98\xa8"
#define ICON_FA_TACHOMETER_AVERAGE "\xef\x98\xa9"
#define ICON_FA_TACHOMETER_FAST "\xef\x98\xaa"
#define ICON_FA_TACHOMETER_FASTEST "\xef\x98\xab"
#define ICON_FA_TACHOMETER_SLOW "\xef\x98\xac"
#define ICON_FA_TACHOMETER_SLOWEST "\xef\x98\xad"
#define ICON_FA_TACO "\xef\xa0\xa6"
#define ICON_FA_TAG "\xef\x80\xab"
#define ICON_FA_TAGS "\xef\x80\xac"
#define ICON_FA_TALLY "\xef\x9a\x9c"
#define ICON_FA_TANAKH "\xef\xa0\xa7"
#define ICON_FA_TAPE "\xef\x93\x9b"
#define ICON_FA_TASKS "\xef\x82\xae"
#define ICON_FA_TASKS_ALT "\xef\xa0\xa8"
#define ICON_FA_TAXI "\xef\x86\xba"
#define ICON_FA_TEETH "\xef\x98\xae"
#define ICON_FA_TEETH_OPEN "\xef\x98\xaf"
#define ICON_FA_TELESCOPE "\xee\x80\xbe"
#define ICON_FA_TEMPERATURE_DOWN "\xee\x80\xbf"
#define ICON_FA_TEMPERATURE_FRIGID "\xef\x9d\xa8"
#define ICON_FA_TEMPERATURE_HIGH "\xef\x9d\xa9"
#define ICON_FA_TEMPERATURE_HOT "\xef\x9d\xaa"
#define ICON_FA_TEMPERATURE_LOW "\xef\x9d\xab"
#define ICON_FA_TEMPERATURE_UP "\xee\x81\x80"
#define ICON_FA_TENGE "\xef\x9f\x97"
#define ICON_FA_TENNIS_BALL "\xef\x91\x9e"
#define ICON_FA_TERMINAL "\xef\x84\xa0"
#define ICON_FA_TEXT "\xef\xa2\x93"
#define ICON_FA_TEXT_HEIGHT "\xef\x80\xb4"
#define ICON_FA_TEXT_SIZE "\xef\xa2\x94"
#define ICON_FA_TEXT_WIDTH "\xef\x80\xb5"
#define ICON_FA_TH "\xef\x80\x8a"
#define ICON_FA_TH_LARGE "\xef\x80\x89"
#define ICON_FA_TH_LIST "\xef\x80\x8b"
#define ICON_FA_THEATER_MASKS "\xef\x98\xb0"
#define ICON_FA_THERMOMETER "\xef\x92\x91"
#define ICON_FA_THERMOMETER_EMPTY "\xef\x8b\x8b"
#define ICON_FA_THERMOMETER_FULL "\xef\x8b\x87"
#define ICON_FA_THERMOMETER_HALF "\xef\x8b\x89"
#define ICON_FA_THERMOMETER_QUARTER "\xef\x8b\x8a"
#define ICON_FA_THERMOMETER_THREE_QUARTERS "\xef\x8b\x88"
#define ICON_FA_THETA "\xef\x9a\x9e"
#define ICON_FA_THUMBS_DOWN "\xef\x85\xa5"
#define ICON_FA_THUMBS_UP "\xef\x85\xa4"
#define ICON_FA_THUMBTACK "\xef\x82\x8d"
#define ICON_FA_THUNDERSTORM "\xef\x9d\xac"
#define ICON_FA_THUNDERSTORM_MOON "\xef\x9d\xad"
#define ICON_FA_THUNDERSTORM_SUN "\xef\x9d\xae"
#define ICON_FA_TICKET "\xef\x85\x85"
#define ICON_FA_TICKET_ALT "\xef\x8f\xbf"
#define ICON_FA_TILDE "\xef\x9a\x9f"
#define ICON_FA_TIMES "\xef\x80\x8d"
#define ICON_FA_TIMES_CIRCLE "\xef\x81\x97"
#define ICON_FA_TIMES_HEXAGON "\xef\x8b\xae"
#define ICON_FA_TIMES_OCTAGON "\xef\x8b\xb0"
#define ICON_FA_TIMES_SQUARE "\xef\x8b\x93"
#define ICON_FA_TINT "\xef\x81\x83"
#define ICON_FA_TINT_SLASH "\xef\x97\x87"
#define ICON_FA_TIRE "\xef\x98\xb1"
#define ICON_FA_TIRE_FLAT "\xef\x98\xb2"
#define ICON_FA_TIRE_PRESSURE_WARNING "\xef\x98\xb3"
#define ICON_FA_TIRE_RUGGED "\xef\x98\xb4"
#define ICON_FA_TIRED "\xef\x97\x88"
#define ICON_FA_TOGGLE_OFF "\xef\x88\x84"
#define ICON_FA_TOGGLE_ON "\xef\x88\x85"
#define ICON_FA_TOILET "\xef\x9f\x98"
#define ICON_FA_TOILET_PAPER "\xef\x9c\x9e"
#define ICON_FA_TOILET_PAPER_ALT "\xef\x9c\x9f"
#define ICON_FA_TOILET_PAPER_SLASH "\xee\x81\xb2"
#define ICON_FA_TOMBSTONE "\xef\x9c\xa0"
#define ICON_FA_TOMBSTONE_ALT "\xef\x9c\xa1"
#define ICON_FA_TOOLBOX "\xef\x95\x92"
#define ICON_FA_TOOLS "\xef\x9f\x99"
#define ICON_FA_TOOTH "\xef\x97\x89"
#define ICON_FA_TOOTHBRUSH "\xef\x98\xb5"
#define ICON_FA_TORAH "\xef\x9a\xa0"
#define ICON_FA_TORII_GATE "\xef\x9a\xa1"
#define ICON_FA_TORNADO "\xef\x9d\xaf"
#define ICON_FA_TRACTOR "\xef\x9c\xa2"
#define ICON_FA_TRADEMARK "\xef\x89\x9c"
#define ICON_FA_TRAFFIC_CONE "\xef\x98\xb6"
#define ICON_FA_TRAFFIC_LIGHT "\xef\x98\xb7"
#define ICON_FA_TRAFFIC_LIGHT_GO "\xef\x98\xb8"
#define ICON_FA_TRAFFIC_LIGHT_SLOW "\xef\x98\xb9"
#define ICON_FA_TRAFFIC_LIGHT_STOP "\xef\x98\xba"
#define ICON_FA_TRAILER "\xee\x81\x81"
#define ICON_FA_TRAIN "\xef\x88\xb8"
#define ICON_FA_TRAM "\xef\x9f\x9a"
#define ICON_FA_TRANSGENDER "\xef\x88\xa4"
#define ICON_FA_TRANSGENDER_ALT "\xef\x88\xa5"
#define ICON_FA_TRANSPORTER "\xee\x81\x82"
#define ICON_FA_TRANSPORTER_1 "\xee\x81\x83"
#define ICON_FA_TRANSPORTER_2 "\xee\x81\x84"
#define ICON_FA_TRANSPORTER_3 "\xee\x81\x85"
#define ICON_FA_TRANSPORTER_EMPTY "\xee\x81\x86"
#define ICON_FA_TRASH "\xef\x87\xb8"
#define ICON_FA_TRASH_ALT "\xef\x8b\xad"
#define ICON_FA_TRASH_RESTORE "\xef\xa0\xa9"
#define ICON_FA_TRASH_RESTORE_ALT "\xef\xa0\xaa"
#define ICON_FA_TRASH_UNDO "\xef\xa2\x95"
#define ICON_FA_TRASH_UNDO_ALT "\xef\xa2\x96"
#define ICON_FA_TREASURE_CHEST "\xef\x9c\xa3"
#define ICON_FA_TREE "\xef\x86\xbb"
#define ICON_FA_TREE_ALT "\xef\x90\x80"
#define ICON_FA_TREE_CHRISTMAS "\xef\x9f\x9b"
#define ICON_FA_TREE_DECORATED "\xef\x9f\x9c"
#define ICON_FA_TREE_LARGE "\xef\x9f\x9d"
#define ICON_FA_TREE_PALM "\xef\xa0\xab"
#define ICON_FA_TREES "\xef\x9c\xa4"
#define ICON_FA_TRIANGLE "\xef\x8b\xac"
#define ICON_FA_TRIANGLE_MUSIC "\xef\xa3\xa2"
#define ICON_FA_TROPHY "\xef\x82\x91"
#define ICON_FA_TROPHY_ALT "\xef\x8b\xab"
#define ICON_FA_TRUCK "\xef\x83\x91"
#define ICON_FA_TRUCK_CONTAINER "\xef\x93\x9c"
#define ICON_FA_TRUCK_COUCH "\xef\x93\x9d"
#define ICON_FA_TRUCK_LOADING "\xef\x93\x9e"
#define ICON_FA_TRUCK_MONSTER "\xef\x98\xbb"
#define ICON_FA_TRUCK_MOVING "\xef\x93\x9f"
#define ICON_FA_TRUCK_PICKUP "\xef\x98\xbc"
#define ICON_FA_TRUCK_PLOW "\xef\x9f\x9e"
#define ICON_FA_TRUCK_RAMP "\xef\x93\xa0"
#define ICON_FA_TRUMPET "\xef\xa3\xa3"
#define ICON_FA_TSHIRT "\xef\x95\x93"
#define ICON_FA_TTY "\xef\x87\xa4"
#define ICON_FA_TURKEY "\xef\x9c\xa5"
#define ICON_FA_TURNTABLE "\xef\xa3\xa4"
#define ICON_FA_TURTLE "\xef\x9c\xa6"
#define ICON_FA_TV "\xef\x89\xac"
#define ICON_FA_TV_ALT "\xef\xa3\xa5"
#define ICON_FA_TV_MUSIC "\xef\xa3\xa6"
#define ICON_FA_TV_RETRO "\xef\x90\x81"
#define ICON_FA_TYPEWRITER "\xef\xa3\xa7"
#define ICON_FA_UFO "\xee\x81\x87"
#define ICON_FA_UFO_BEAM "\xee\x81\x88"
#define ICON_FA_UMBRELLA "\xef\x83\xa9"
#define ICON_FA_UMBRELLA_BEACH "\xef\x97\x8a"
#define ICON_FA_UNDERLINE "\xef\x83\x8d"
#define ICON_FA_UNDO "\xef\x83\xa2"
#define ICON_FA_UNDO_ALT "\xef\x8b\xaa"
#define ICON_FA_UNICORN "\xef\x9c\xa7"
#define ICON_FA_UNION "\xef\x9a\xa2"
#define ICON_FA_UNIVERSAL_ACCESS "\xef\x8a\x9a"
#define ICON_FA_UNIVERSITY "\xef\x86\x9c"
#define ICON_FA_UNLINK "\xef\x84\xa7"
#define ICON_FA_UNLOCK "\xef\x82\x9c"
#define ICON_FA_UNLOCK_ALT "\xef\x84\xbe"
#define ICON_FA_UPLOAD "\xef\x82\x93"
#define ICON_FA_USB_DRIVE "\xef\xa3\xa9"
#define ICON_FA_USD_CIRCLE "\xef\x8b\xa8"
#define ICON_FA_USD_SQUARE "\xef\x8b\xa9"
#define ICON_FA_USER "\xef\x80\x87"
#define ICON_FA_USER_ALIEN "\xee\x81\x8a"
#define ICON_FA_USER_ALT "\xef\x90\x86"
#define ICON_FA_USER_ALT_SLASH "\xef\x93\xba"
#define ICON_FA_USER_ASTRONAUT "\xef\x93\xbb"
#define ICON_FA_USER_CHART "\xef\x9a\xa3"
#define ICON_FA_USER_CHECK "\xef\x93\xbc"
#define ICON_FA_USER_CIRCLE "\xef\x8a\xbd"
#define ICON_FA_USER_CLOCK "\xef\x93\xbd"
#define ICON_FA_USER_COG "\xef\x93\xbe"
#define ICON_FA_USER_COWBOY "\xef\xa3\xaa"
#define ICON_FA_USER_CROWN "\xef\x9a\xa4"
#define ICON_FA_USER_EDIT "\xef\x93\xbf"
#define ICON_FA_USER_FRIENDS "\xef\x94\x80"
#define ICON_FA_USER_GRADUATE "\xef\x94\x81"
#define ICON_FA_USER_HARD_HAT "\xef\xa0\xac"
#define ICON_FA_USER_HEADSET "\xef\xa0\xad"
#define ICON_FA_USER_INJURED "\xef\x9c\xa8"
#define ICON_FA_USER_LOCK "\xef\x94\x82"
#define ICON_FA_USER_MD "\xef\x83\xb0"
#define ICON_FA_USER_MD_CHAT "\xef\xa0\xae"
#define ICON_FA_USER_MINUS "\xef\x94\x83"
#define ICON_FA_USER_MUSIC "\xef\xa3\xab"
#define ICON_FA_USER_NINJA "\xef\x94\x84"
#define ICON_FA_USER_NURSE "\xef\xa0\xaf"
#define ICON_FA_USER_PLUS "\xef\x88\xb4"
#define ICON_FA_USER_ROBOT "\xee\x81\x8b"
#define ICON_FA_USER_SECRET "\xef\x88\x9b"
#define ICON_FA_USER_SHIELD "\xef\x94\x85"
#define ICON_FA_USER_SLASH "\xef\x94\x86"
#define ICON_FA_USER_TAG "\xef\x94\x87"
#define ICON_FA_USER_TIE "\xef\x94\x88"
#define ICON_FA_USER_TIMES "\xef\x88\xb5"
#define ICON_FA_USER_UNLOCK "\xee\x81\x98"
#define ICON_FA_USER_VISOR "\xee\x81\x8c"
#define ICON_FA_USERS "\xef\x83\x80"
#define ICON_FA_USERS_CLASS "\xef\x98\xbd"
#define ICON_FA_USERS_COG "\xef\x94\x89"
#define ICON_FA_USERS_CROWN "\xef\x9a\xa5"
#define ICON_FA_USERS_MEDICAL "\xef\xa0\xb0"
#define ICON_FA_USERS_SLASH "\xee\x81\xb3"
#define ICON_FA_UTENSIL_FORK "\xef\x8b\xa3"
#define ICON_FA_UTENSIL_KNIFE "\xef\x8b\xa4"
#define ICON_FA_UTENSIL_SPOON "\xef\x8b\xa5"
#define ICON_FA_UTENSILS "\xef\x8b\xa7"
#define ICON_FA_UTENSILS_ALT "\xef\x8b\xa6"
#define ICON_FA_VACUUM "\xee\x81\x8d"
#define ICON_FA_VACUUM_ROBOT "\xee\x81\x8e"
#define ICON_FA_VALUE_ABSOLUTE "\xef\x9a\xa6"
#define ICON_FA_VECTOR_SQUARE "\xef\x97\x8b"
#define ICON_FA_VENUS "\xef\x88\xa1"
#define ICON_FA_VENUS_DOUBLE "\xef\x88\xa6"
#define ICON_FA_VENUS_MARS "\xef\x88\xa8"
#define ICON_FA_VHS "\xef\xa3\xac"
#define ICON_FA_VIAL "\xef\x92\x92"
#define ICON_FA_VIALS "\xef\x92\x93"
#define ICON_FA_VIDEO "\xef\x80\xbd"
#define ICON_FA_VIDEO_PLUS "\xef\x93\xa1"
#define ICON_FA_VIDEO_SLASH "\xef\x93\xa2"
#define ICON_FA_VIHARA "\xef\x9a\xa7"
#define ICON_FA_VIOLIN "\xef\xa3\xad"
#define ICON_FA_VIRUS "\xee\x81\xb4"
#define ICON_FA_VIRUS_SLASH "\xee\x81\xb5"
#define ICON_FA_VIRUSES "\xee\x81\xb6"
#define ICON_FA_VOICEMAIL "\xef\xa2\x97"
#define ICON_FA_VOLCANO "\xef\x9d\xb0"
#define ICON_FA_VOLLEYBALL_BALL "\xef\x91\x9f"
#define ICON_FA_VOLUME "\xef\x9a\xa8"
#define ICON_FA_VOLUME_DOWN "\xef\x80\xa7"
#define ICON_FA_VOLUME_MUTE "\xef\x9a\xa9"
#define ICON_FA_VOLUME_OFF "\xef\x80\xa6"
#define ICON_FA_VOLUME_SLASH "\xef\x8b\xa2"
#define ICON_FA_VOLUME_UP "\xef\x80\xa8"
#define ICON_FA_VOTE_NAY "\xef\x9d\xb1"
#define ICON_FA_VOTE_YEA "\xef\x9d\xb2"
#define ICON_FA_VR_CARDBOARD "\xef\x9c\xa9"
#define ICON_FA_WAGON_COVERED "\xef\xa3\xae"
#define ICON_FA_WALKER "\xef\xa0\xb1"
#define ICON_FA_WALKIE_TALKIE "\xef\xa3\xaf"
#define ICON_FA_WALKING "\xef\x95\x94"
#define ICON_FA_WALLET "\xef\x95\x95"
#define ICON_FA_WAND "\xef\x9c\xaa"
#define ICON_FA_WAND_MAGIC "\xef\x9c\xab"
#define ICON_FA_WAREHOUSE "\xef\x92\x94"
#define ICON_FA_WAREHOUSE_ALT "\xef\x92\x95"
#define ICON_FA_WASHER "\xef\xa2\x98"
#define ICON_FA_WATCH "\xef\x8b\xa1"
#define ICON_FA_WATCH_CALCULATOR "\xef\xa3\xb0"
#define ICON_FA_WATCH_FITNESS "\xef\x98\xbe"
#define ICON_FA_WATER "\xef\x9d\xb3"
#define ICON_FA_WATER_LOWER "\xef\x9d\xb4"
#define ICON_FA_WATER_RISE "\xef\x9d\xb5"
#define ICON_FA_WAVE_SINE "\xef\xa2\x99"
#define ICON_FA_WAVE_SQUARE "\xef\xa0\xbe"
#define ICON_FA_WAVE_TRIANGLE "\xef\xa2\x9a"
#define ICON_FA_WAVEFORM "\xef\xa3\xb1"
#define ICON_FA_WAVEFORM_PATH "\xef\xa3\xb2"
#define ICON_FA_WEBCAM "\xef\xa0\xb2"
#define ICON_FA_WEBCAM_SLASH "\xef\xa0\xb3"
#define ICON_FA_WEIGHT "\xef\x92\x96"
#define ICON_FA_WEIGHT_HANGING "\xef\x97\x8d"
#define ICON_FA_WHALE "\xef\x9c\xac"
#define ICON_FA_WHEAT "\xef\x9c\xad"
#define ICON_FA_WHEELCHAIR "\xef\x86\x93"
#define ICON_FA_WHISTLE "\xef\x91\xa0"
#define ICON_FA_WIFI "\xef\x87\xab"
#define ICON_FA_WIFI_1 "\xef\x9a\xaa"
#define ICON_FA_WIFI_2 "\xef\x9a\xab"
#define ICON_FA_WIFI_SLASH "\xef\x9a\xac"
#define ICON_FA_WIND "\xef\x9c\xae"
#define ICON_FA_WIND_TURBINE "\xef\xa2\x9b"
#define ICON_FA_WIND_WARNING "\xef\x9d\xb6"
#define ICON_FA_WINDOW "\xef\x90\x8e"
#define ICON_FA_WINDOW_ALT "\xef\x90\x8f"
#define ICON_FA_WINDOW_CLOSE "\xef\x90\x90"
#define ICON_FA_WINDOW_FRAME "\xee\x81\x8f"
#define ICON_FA_WINDOW_FRAME_OPEN "\xee\x81\x90"
#define ICON_FA_WINDOW_MAXIMIZE "\xef\x8b\x90"
#define ICON_FA_WINDOW_MINIMIZE "\xef\x8b\x91"
#define ICON_FA_WINDOW_RESTORE "\xef\x8b\x92"
#define ICON_FA_WINDSOCK "\xef\x9d\xb7"
#define ICON_FA_WINE_BOTTLE "\xef\x9c\xaf"
#define ICON_FA_WINE_GLASS "\xef\x93\xa3"
#define ICON_FA_WINE_GLASS_ALT "\xef\x97\x8e"
#define ICON_FA_WON_SIGN "\xef\x85\x99"
#define ICON_FA_WREATH "\xef\x9f\xa2"
#define ICON_FA_WRENCH "\xef\x82\xad"
#define ICON_FA_X_RAY "\xef\x92\x97"
#define ICON_FA_YEN_SIGN "\xef\x85\x97"
#define ICON_FA_YIN_YANG "\xef\x9a\xad"
